function [RcatOut]=CombineSRAndLRRadials(RcatLongRange,RcatStandardRange,LRMask,SRMask,NewRes,MaxRangeDiff,GridSlop,LogFileDir,LogFileName)
%
%  [RcatOut]=CombineSRAndLRRadials(RcatLongRange,RcatStandardRange,LRMask,S
%  RMask,NewRes,MaxRangeDiff,GridSlop,LogFileDir,LogFileName);
%
%  Uses interp, not average to get grids prior to combining with averaging!  So most often used to get "higher res" LR,
%  and combine with SR
%
%  new grid calculated internally, uses masks to do this
%
%  can pass NaNs for the radial structures if no valid radials.  Can use to
%  interpolate single structures on a common grid then.
%
%  LogFileDir and LogFileName don't have to be specified if we don;t need a comments log
%  file.  Either specify both or none!
%
%
%  Take a little more care with the grid definition  (so we don't have too
%  many).  Make it a ture radial grid now.
%
if isstruct(RcatLongRange),
    TemSite=RcatLongRange.SiteOrigin;
end
%
if ~exist('TemSite','var'),
    if isstruct(RcatStandardRange),
        TemSite=RcatStandardRange.SiteOrigin;
    else
        %
        %  no data in the sites
        %
        RcatOut=NaN;
        return;
    end
end
%
[s,a12,a21]=m_idist([LRMask(:,1);SRMask(:,1)],[LRMask(:,2);SRMask(:,2)],TemSite(1),TemSite(2),'wgs84');
s=s/1000;
%
TemRange=NewRes:NewRes:(nanmax(s)+(2*NewRes));
TemBear=0:5:360;  % using 5 degree angle separation
%
[TemRange,TemBear] = meshgrid(TemRange,TemBear);  % bear in true convention, not math, here
%
% Generate equivalent lon, lat and headings using m_fdist
[TemLon,TemLat,head] = m_fdist(TemSite(1),TemSite(2),TemBear,1000*TemRange,'wgs84');
TemLon(TemLon>180)=TemLon(TemLon>180)-360;  % western hemisphere
TemLon=reshape(TemLon,numel(TemLon),1);
TemLat=reshape(TemLat,numel(TemLat),1);
%
IndicesCheckTem1=inpolygon(TemLon,TemLat,LRMask(:,1),LRMask(:,2));
IndicesCheckTem2=inpolygon(TemLon,TemLat,SRMask(:,1),SRMask(:,2));
%
IndicesCheckTem1=IndicesCheckTem1+IndicesCheckTem2;
clear IndicesCheckTem2
%
temmark=find(IndicesCheckTem1>0);
if numel(temmark)>0,
    TemLon=TemLon(temmark);
    TemLat=TemLat(temmark);
else
    disp('grids defined incorrectly')
    disp('routine ending')
    RcatOut=NaN;
    return;
end
%
%  mask the radials in case that has not happened
%
if isstruct(RcatLongRange),
    [RcatLongRange,I] = maskRadials(RcatLongRange,LRMask);
end
%
if isstruct(RcatStandardRange),
    [RcatStandardRange,I] = maskRadials(RcatStandardRange,SRMask);
end
%
if exist('LogFileDir','var'),
    AddLineToLog(LogFileDir,LogFileName,['obtaining regridded data for first set of radials']);
end
%
disp('obtaining regridded data for first set of radials')
pause(1);
%
if exist('LogFileDir','var'),
    RcatLongRange=GetNewRadialsInterp(RcatLongRange,TemLon,TemLat,MaxRangeDiff,GridSlop,LogFileDir,LogFileName);
else
    RcatLongRange=GetNewRadialsInterp(RcatLongRange,TemLon,TemLat,MaxRangeDiff,GridSlop);  % returning NaN (instead of a structure) is o.k.  
end
%
if exist('LogFileDir','var'),
    AddLineToLog(LogFileDir,LogFileName,['obtaining regridded data for second set of radials']);
end
%
disp('obtaining regridded data for second set of radials')
pause(1);
%
if exist('LogFileDir','var'),
    RcatStandardRange=GetNewRadialsInterp(RcatStandardRange,TemLon,TemLat,MaxRangeDiff,GridSlop,LogFileDir,LogFileName);  % NaN just means no valid radials in structure
else
    RcatStandardRange=GetNewRadialsInterp(RcatStandardRange,TemLon,TemLat,MaxRangeDiff,GridSlop);  % NaN just means no valid radials in structure
end
%
if exist('LogFileDir','var'),
    AddLineToLog(LogFileDir,LogFileName,['Combining both sets of radials']);
end
%
RcatOut=SetUpOutputRadials(RcatLongRange,RcatStandardRange);  % both are on the same grid at this point
%
return;
%
function [RcatTem]=GetNewRadialsInterp(RcatIn,LonIn,LatIn,MaxRangeDiff,GridSlop,LogFileDir,LogFileName)
%
%  to get radials on a new grid
%  Note that some of the old measurements will be NaNs  - take care when
%  interpolating
%
if ~isstruct(RcatIn),
    RcatTem=NaN;
    return;
end
%
if isfield(RcatIn,'TempStats'),
    RcatIn=rmfield(RcatIn,'TempStats');
end
%
if isfield(RcatIn,'SpatialStats'),
    RcatIn=rmfield(RcatIn,'SpatialStats');
end
%
ThetaConv=pi/180;
%
RcatTem=RcatIn;
RcatTem.LonLat=[LonIn LatIn];
%
[NumOldGrids,NumOldTimes]=size(RcatIn.U);
RcatTem.U=NaN*ones(numel(LonIn),NumOldTimes);
RcatTem.V=NaN*ones(numel(LonIn),NumOldTimes);
RcatTem.RadComp=NaN*ones(numel(LonIn),NumOldTimes);
RcatTem.Error=NaN*ones(numel(LonIn),NumOldTimes);
RcatTem.Flag=NaN*ones(numel(LonIn),NumOldTimes);
RcatTem.RangeBearHead=NaN*ones(numel(LonIn),3);
%
[range,bear,head]=m_idist(RcatTem.SiteOrigin(1),RcatTem.SiteOrigin(2),RcatTem.LonLat(:,1),...
    RcatTem.LonLat(:,2),'wgs84');
%
head = true2math( head );
bear = true2math( bear );
%
range=range/1000;
%
RcatTem.RangeBearHead=[reshape(range,numel(range),1) reshape(bear,numel(bear),1) reshape(head,numel(head),1)];
%
%  NaNs can mess up the interpolation in certain cases!  So must loop and
%  be careful.
%
%  set up interpolation matrices
%
[sold,a12old,a21]=m_idist(RcatIn.SiteOrigin(1),RcatIn.SiteOrigin(2),RcatIn.LonLat(:,1),RcatIn.LonLat(:,2),'wgs84');
%
[snew,a12new,a21]=m_idist(RcatTem.SiteOrigin(1),RcatTem.SiteOrigin(2),RcatTem.LonLat(:,1),RcatTem.LonLat(:,2),'wgs84');
%
% deal with wraparound (use +/- 20 degrees or so)...  onnly works if we
%  have continuous 0-360 measurements, otherwise makes no difference
AngleCut=20;
TemmarkAngle1=find(a12old<=AngleCut);
if numel(TemmarkAngle1)>0,
    NewAngles1=a12old(TemmarkAngle1)+360;
    NewS1=sold(TemmarkAngle1);
    NewRad1=RcatIn.RadComp(TemmarkAngle1,:);
    NewErr1=RcatIn.Error(TemmarkAngle1,:);
else
    NewAngles1=[];
    NewS1=[];
    NewRad1=[];
    NewErr1=[];
end
TemmarkAngle2=find(a12old>=(360-AngleCut));
if numel(TemmarkAngle2)>0,
    NewAngles2=a12old(TemmarkAngle2)-360;
    NewS2=sold(TemmarkAngle2);
    NewRad2=RcatIn.RadComp(TemmarkAngle2,:);
    NewErr2=RcatIn.Error(TemmarkAngle2,:);
else
    NewAngles2=[];
    NewS2=[];
    NewRad2=[];
    NewErr2=[];
end
%
a12old=[a12old;NewAngles1;NewAngles2];
sold=[sold;NewS1;NewS2];
RadCompOld=[RcatIn.RadComp;NewRad1;NewRad2];
ErrOld=[RcatIn.Error;NewErr1;NewErr2];
%
%  now loop and grid data
%
for jtime=1:NumOldTimes,
    %
    if isequal(rem(jtime,50),0),
        TemStr=[RcatIn.SiteName ' : Gridding Data:  Time ' num2str(jtime) ' of ' num2str(NumOldTimes)];
        disp(TemStr)
        if exist('LogFileDir','var'),
            AddLineToLog(LogFileDir,LogFileName,TemStr);
        end
    end
    %
    temmark=find(~isnan(RadCompOld(:,jtime)));
    if numel(temmark)>0,
        try
            RcatTem.RadComp(:,jtime)=griddata(sold(temmark)/1000,a12old(temmark),RadCompOld(temmark,jtime),snew/1000,a12new);
            RcatTem.Error(:,jtime)=griddata(sold(temmark)/1000,a12old(temmark),ErrOld(temmark,jtime),snew/1000,a12new);
            %
            GriddedOk=1;
        catch
            GriddedOk=0;
        end
        %
        if GriddedOk,
            %
            %  keep only valid measurements
            %
            [RcatTem.RadComp(:,jtime),RcatTem.Error(:,jtime)]=CheckMeasForValidity(RcatTem.RadComp(:,jtime),...
                RcatTem.Error(:,jtime),RcatTem.LonLat,jtime,RcatIn,MaxRangeDiff,GridSlop);
            %
            RcatTem.U(:,jtime)=RcatTem.RadComp(:,jtime).*cos(ThetaConv*RcatTem.RangeBearHead(:,3));
            RcatTem.V(:,jtime)=RcatTem.RadComp(:,jtime).*sin(ThetaConv*RcatTem.RangeBearHead(:,3));
            RcatTem.Flag(:,jtime)=isfinite(RcatTem.RadComp(:,jtime));
            %
        else
            RcatTem.RadComp(:,jtime)=NaN;
            RcatTem.Error(:,jtime)=NaN;
            disp(['could not grid the data, timestep ' num2str(jtime)])
        end
    end
end
%
%  we now have valid data
%
return;
%
function [RadNew,ErrNew]=CheckMeasForValidity(RadNew,ErrNew,LonLatNew,TimeIndex,RcatIn,MaxRangeDiff,GridSlop)
%
%  [RadNew,ErrNew]=CheckMeasForValidity(RadNew,ErrNew,LonLatNew,TimeIndex,R
%  catIn,MaxRangeDiff,GridSlop);
%
%  now find those that are valid
%
%  this sets measurements that do not meet the criteria to NaNs
%
%  Chunking points in pieces to save time, but can't do all at once b/c of
%  memory issues.
%
ChunkSize=3000;
%
TemSite=RcatIn.SiteName;
CheckingDate=datevec(RcatIn.TimeStamp(TimeIndex));
DateInfoMessage=['   Year ' num2str(CheckingDate(1)) '  Month ' num2str(CheckingDate(2)) '  Day  ' num2str(CheckingDate(3))...
    '  Hour  ' num2str(CheckingDate(4))];
clear CheckingDate
%
temmark=find(~isnan(RcatIn.RadComp(:,TimeIndex)));
if numel(temmark)<2,  % strictly, less than 1, but want to deal with matrices below
    RadNew=NaN*ones(size(RadNew));
    ErrNew=NaN*ones(size(ErrNew));
    return;
else
    OldLonLat=RcatIn.LonLat(temmark,:);  % OldLonLat already has been screened for valid entries only
    clear RcatIn
end
%
NumOldLon=numel(OldLonLat(:,1));
NumNewLon=numel(LonLatNew(:,1));
%
%  we have memory problems!  Oof.
%
%  Loop through, I guess.
%
%  to save time, try doing all at once, but have a catch statement if we
%  cannot
%
%  set to NaNs points that are too far outside the coverage area - rough
%  cut
%
[LonRightCut,lat2,a21]=m_fdist(max(OldLonLat(:,1)),max(OldLonLat(:,2)),90,(1.5*1000*MaxRangeDiff),'wgs84');
if LonRightCut>0,  % western hem
    LonRightCut=LonRightCut-360;
end
[LonLeftCut,lat2,a21]=m_fdist(min(OldLonLat(:,1)),max(OldLonLat(:,2)),270,(1.5*1000*MaxRangeDiff),'wgs84');
if LonLeftCut>0,  % western hem
    LonLeftCut=LonLeftCut-360;
end
[Lon2,LatTopCut,a21]=m_fdist(max(OldLonLat(:,1)),max(OldLonLat(:,2)),0,(1.5*1000*MaxRangeDiff),'wgs84');
[Lon2,LatBotCut,a21]=m_fdist(max(OldLonLat(:,1)),min(OldLonLat(:,2)),180,(1.5*1000*MaxRangeDiff),'wgs84');
%
FlagLon=find((LonLatNew(:,1)>LonRightCut)|(LonLatNew(:,1)<LonLeftCut));
FlagLat=find((LonLatNew(:,2)>LatTopCut)|(LonLatNew(:,2)<LatBotCut));
%
if numel(FlagLon)>0,
    RadNew(FlagLon)=NaN;
    ErrNew(FlagLon)=NaN;
end
%
if numel(FlagLat)>0,
    RadNew(FlagLat)=NaN;
    ErrNew(FlagLat)=NaN;
end
%
CheckValidPoints=find(~isnan(RadNew));
if numel(CheckValidPoints)>0,
    RadNewCheck=RadNew(CheckValidPoints);
    ErrNewCheck=ErrNew(CheckValidPoints);
    LonLatNew=LonLatNew(CheckValidPoints,:);  %  redefined!  Don't rely on later when referencing original array
    NumNewLon=numel(LonLatNew(:,1));
else
    return;
end
%
%  try do so all at once
%
try
    TemStr=[TemSite ': TimeIndex : ' num2str(TimeIndex) ' : Trying to check Points all at once'];
    disp(TemStr);
    %
    NewLonMatrix=LonLatNew(:,1)*ones(1,NumOldLon);
    NewLatMatrix=LonLatNew(:,2)*ones(1,NumOldLon);
    %
    [s,a12,a21] = m_idist(NewLonMatrix,NewLatMatrix,ones(NumNewLon,1)*OldLonLat(:,1)',ones(NumNewLon,1)*OldLonLat(:,2)','wgs84');
    %
    %
    %  NaNs will occur if points are too close
    %
    temmark=find(isnan(s));
    if numel(temmark)>0,
        s(temmark)=0;
        a12(temmark)=0;
        a21(temmark)=0;
    end
    %
    %
    s=s/1000;
    %
    KeepPointGridSlop=sign(sum(s'<GridSlop));  % points that are close we will keep.  A row vector (or single entry)
    %
    s(s>=MaxRangeDiff)=NaN;
    %
    %         temmark=find(isnan(s));  % not using the angle criterion anymore.
    %                                     A bit of overkill.
    %         if numel(temmark)>0,
    %             a12(temmark)=NaN;
    %         end
    %
    NumPointsNearby=sum(~isnan(s'));  % A row vector (or single entry)
    %
    %         temmark=find(~isnan(a12));  % old code, not adapted for this
    %                                       routine.  Not using the angle
    %                                       criterion anymore.
    %
    %         if numel(temmark)>1,
    %             [AngleDiff,anglePair] = angSpread2(a12(temmark));
    %         else
    %             AngleDiff=NaN;
    %         end
    %         %
    %         AngleDiff(AngleDiff<90)=NaN;
    %
    NumPointsNearby(NumPointsNearby<2)=0;
    NumPointsNearby(NumPointsNearby>=2)=1;
    %
    ValidPointMarkers=sign(NumPointsNearby+KeepPointGridSlop);  % 1 means valid points, zeros mean not valid
    %
    temmark=find(ValidPointMarkers<0.5);
    %
    if numel(temmark)>0,
        RadNewCheck(temmark)=NaN;
        ErrNewCheck(temmark)=NaN;
    end
    %
catch
    %
    clear NewLonMatrix NewLatMatrix
    %
    OldLonMatrix=ones(ChunkSize,1)*OldLonLat(:,1)';  % will use in the checking routine
    OldLatMatrix=ones(ChunkSize,1)*OldLonLat(:,2)';
    %
    disp('checking points for validity - very slow b/c of memory issues')
    %
    PointCheckStart=1;
    %
    while PointCheckStart<=NumNewLon,
        %
        PointCheckEnd=PointCheckStart+ChunkSize-1;
        if PointCheckEnd>NumNewLon,
            PointCheckEnd=NumNewLon;
        end
        %
        TemStr=[TemSite ': TimeIndex : ' num2str(TimeIndex) ' : Checking Point ' num2str(PointCheckStart) ' of ' num2str(NumNewLon)];
        disp(TemStr);
        disp(DateInfoMessage);
        %
        NewLonMatrix=LonLatNew(PointCheckStart:PointCheckEnd,1)*ones(1,NumOldLon);
        NewLatMatrix=LonLatNew(PointCheckStart:PointCheckEnd,2)*ones(1,NumOldLon);
        %
        NumPointsUsed=PointCheckEnd-PointCheckStart+1;
        %
        [s,a12,a21] = m_idist(NewLonMatrix,NewLatMatrix,OldLonMatrix(1:NumPointsUsed,:),OldLatMatrix(1:NumPointsUsed,:),'wgs84');
        %
        %  NaNs will occur if points are too close
        %
        temmark=find(isnan(s));
        if numel(temmark)>0,
            s(temmark)=0;
            a12(temmark)=0;
            a21(temmark)=0;
        end
        %
        %
        s=s/1000;
        %
        KeepPointGridSlop=sign(sum(s'<GridSlop));  % points that are close we will keep.  A row vector (or single entry)
        %
        s(s>=MaxRangeDiff)=NaN;
        %
        %         temmark=find(isnan(s));  % not using the angle criterion anymore.
        %                                     A bit of overkill.
        %         if numel(temmark)>0,
        %             a12(temmark)=NaN;
        %         end
        %
        NumPointsNearby=sum(~isnan(s'));  % A row vector (or single entry)
        %
        %         temmark=find(~isnan(a12));  % old code, not adapted for this
        %                                       routine.  Not using the angle
        %                                       criterion anymore.
        %
        %         if numel(temmark)>1,
        %             [AngleDiff,anglePair] = angSpread2(a12(temmark));
        %         else
        %             AngleDiff=NaN;
        %         end
        %         %
        %         AngleDiff(AngleDiff<90)=NaN;
        %
        NumPointsNearby(NumPointsNearby<2)=0;
        NumPointsNearby(NumPointsNearby>=2)=1;
        %
        ValidPointMarkers=sign(NumPointsNearby+KeepPointGridSlop);  % 1 means valid points, zeros mean not valid
        %
        temmark=find(ValidPointMarkers<0.5);
        %
        if numel(temmark)>0,
            InvalidPointIndices=PointCheckStart+temmark-1;
            RadNewCheck(InvalidPointIndices)=NaN;
            ErrNewCheck(InvalidPointIndices)=NaN;
        end
        %
        PointCheckStart=PointCheckEnd+1;
        %
    end
end
%
%  now reset RadNew and ErrNew
%
RadNew(CheckValidPoints)=RadNewCheck;
ErrNew(CheckValidPoints)=ErrNewCheck;
clear ErrNewCheck RadNewCheck
%
return;
%
function [RcatOut]=SetUpOutputRadials(Rcat1,Rcat2)
%
%  [RcatOut]=SetUpOutputRadials(Rcat1,Rcat2);
%
%  both are on the same grid at this point, but may not have the same
%  timestamps or number of measurements
%
%  both may or may not be structures (have valid data)
%
%  SiteOrigin should be close enough in both cases to not matter, and
%  range/bear/heading should be close enough also
%
if (~isstruct(Rcat1))&&(~isstruct(Rcat2)),
    RcatOut=NaN;
    return;
end
%
if ~isstruct(Rcat1),
    RcatOut=Rcat2;
    return;
end
%
if ~isstruct(Rcat2),
    RcatOut=Rcat1;
    return;
end
%
%  we now have both sets of radials to combine
%
%  assume that the "best" resolution is hourly
%
%  They do not have too have the same valid hours
%
RcatOut=Rcat1;
%
DateVec1=datevec(Rcat1.TimeStamp);
temmark=find((DateVec1(:,5)>58)&(DateVec1(:,6)>58));
if numel(temmark)>0,
    DateVec1(temmark,4)=DateVec1(temmark,4)+1;
    DateVec1(temmark,5)=0;
    DateVec1(temmark,6)=0;
end
DateVec1=round(DateVec1);
%
DateVec2=datevec(Rcat2.TimeStamp);
temmark=find((DateVec2(:,5)>58)&(DateVec2(:,6)>58));
if numel(temmark)>0,
    DateVec2(temmark,4)=DateVec2(temmark,4)+1;
    DateVec2(temmark,5)=0;
    DateVec2(temmark,6)=0;
end
DateVec2=round(DateVec2);
%
DateVecAll=unique([DateVec1;DateVec2],'rows');  % result is sorted
%
RcatOut.TimeStamp=datenum(DateVecAll);
RcatOut.TimeStamp=RcatOut.TimeStamp';
NumTimes=numel(RcatOut.TimeStamp);
%
[NumGrids,NumCols]=size(RcatOut.LonLat);
%
RcatOut.RadComp=NaN*ones(NumGrids,NumTimes,2);
RcatOut.U=NaN*ones(NumGrids,NumTimes,2);
RcatOut.V=NaN*ones(NumGrids,NumTimes,2);
RcatOut.Error=NaN*ones(NumGrids,NumTimes,2);
%
[C,IA,IB]=intersect(DateVec1,DateVecAll,'rows');
%
%  we can average components as well b/c we only have mesurements in the
%  radial direction
%
IA=IA'; % transpose just to make the point
IB=IB';
RcatOut.RadComp(:,IB,1)=Rcat1.RadComp(:,IA);
RcatOut.Error(:,IB,1)=Rcat1.Error(:,IA);
RcatOut.U(:,IB,1)=Rcat1.U(:,IA);
RcatOut.V(:,IB,1)=Rcat1.V(:,IA);
%
[C,IA,IB]=intersect(DateVec2,DateVecAll,'rows');
%
%  we can average components as well b/c we only have mesurements in the
%  radial direction
%
IA=IA'; % transpose just to make the point
IB=IB';
RcatOut.RadComp(:,IB,2)=Rcat2.RadComp(:,IA);
RcatOut.Error(:,IB,2)=Rcat2.Error(:,IA);
RcatOut.U(:,IB,2)=Rcat2.U(:,IA);
RcatOut.V(:,IB,2)=Rcat2.V(:,IA);
%
RcatOut.RadComp=nanmean(RcatOut.RadComp,3);
RcatOut.Error=nanmean(RcatOut.Error,3);
RcatOut.U=nanmean(RcatOut.U,3);
RcatOut.V=nanmean(RcatOut.V,3);
%
RcatOut.Flag=isfinite(RcatOut.RadComp);
%
RcatOut.FileName=[];
RcatOut.FileName=cell(1,numel(RcatOut.TimeStamp));
%
return;
%
