function [VelStructNew]=GetHFRadarRunMeanAverages(VelStructIn,DateNumWant,RestrictMeasTo,AveragesWanted)
%
%  GetHFRadarRunMeanAverages(VelStructIn,DateNumWant,RestrictMeasTo,AveragesWanted);
%
%  set up output structure
%
%  hourly input data assumed, and AveragesWanted based on that
%  (AveragesWanted is in hours)
%
%  RestrictTo is a percentage (i.e., 40).  means to return a value when
%  measurements are present at a location 40% or more if the time
%
%  DateNumWant is the datenum axis that we could like the measurements
%  calculated for (so, the output does not have to be a true running mean,
%  but can be if we so choose).  We can simply choose 1 time to output.
%
[NumPos,NumCols]=size(VelStructIn.LonLat);
VelStructNew=TUVstruct([NumPos numel(DateNumWant)],1);
%
VelStructNew.TimeStamp=DateNumWant;
VelStructNew.LonLat=VelStructIn.LonLat;
%
NumMeasNeededPerPos=(RestrictMeasTo/100)*AveragesWanted;
%
TimeDiffToSearch=0.5*(AveragesWanted/24);  %  in days, mult by 0.5 b/c searching on either side of the time in question
%
for jdate=1:numel(DateNumWant),
    %
    MeasSelect=find((VelStructIn.TimeStamp>=(DateNumWant(jdate)-TimeDiffToSearch))&(VelStructIn.TimeStamp<=(DateNumWant(jdate)+TimeDiffToSearch)));
    %
    if numel(MeasSelect)>=NumMeasNeededPerPos, % means we have a shot at getting enough meas at some positions
        %
        TemU=VelStructIn.U(:,MeasSelect);
        TemV=VelStructIn.V(:,MeasSelect);
        %
        MeanU=nanmean(TemU');
        MeanV=nanmean(TemV');
        MeanU=MeanU';
        MeanV=MeanV';
        %
        NumMeasPerPos=sum(~isnan(TemU'));  % should be same for V as well
        NumMeasPerPos=NumMeasPerPos';
        %
        TemPosMark=find(NumMeasPerPos>=NumMeasNeededPerPos);
        %
        if numel(TemPosMark)>0,
            %
            VelStructNew.U(TemPosMark,jdate)=MeanU(TemPosMark);
            VelStructNew.V(TemPosMark,jdate)=MeanV(TemPosMark);
        end
    end
end
%
%  the routine is done
%
return;
%
