function [RadialStats,Rcat]=GetRadialStatistics2(Rorig,RadialMaskFiles,RadialMaskSites)
%
%  [RadialStats,Rcat]=GetRadialStatistics2(Rorig,RadialMaskFiles,RadialMaskSites);
%
%  Based on GetRadialStatistics.  Output is same, methods different, allows user to not
%  worry so much about passing the filenames, etc.
%
%  StartTime and EndTime are the 6 component start and end time vectors
%  RadialMaskFiles is the cell array of mask file names, 1 per site
%  Corresponds to the cell array of RadialMaskSites
%
%  Asssumes that the highest resolution is hourly
%  (uses a small time difference to see if a file is found or not)
%
%  RadialStats has a number of entries equal to Rorig
%
%  Also!!!  Assumes that the files are presented in order of time  (time
%  increasing)
%
%  Also based on the assumption that the user tried to load continuous data
%
%
%  This is a bit redundant and repetitiouus the way that it is set up
%
NumFiles=numel(Rorig);
RadialStats.FileNames=cell(NumFiles,1);
RadialStats.SiteNames=cell(NumFiles,1);  %redundant, given the file name, but will be useful later
RadialStats.FileTimes=NaN*zeros(NumFiles,4);  % also redundant, but will be useful later
RadialStats.FileTimeStamp=NaN*zeros(NumFiles,1);  % time stamp of the file
RadialStats.FileFound=NaN*zeros(NumFiles,1);  % 1 if found, zero if not  (1 is defined to be good in the stats)
RadialStats.DataFound=NaN*zeros(NumFiles,1); % 1 if valid, zero if not
RadialStats.NotWobblyFiles=NaN*zeros(NumFiles,1);  % 1 if not wobbly, zero if wobbly
RadialStats.MatchingTimeStamps=NaN*zeros(NumFiles,1); % 1 if matching, zero if not
RadialStats.GriddedCurrentsUnique=NaN*zeros(NumFiles,1);  % 1 if more than 70% of the gridded currents are different from preeding and following file
RadialStats.NonNanGriddedCurrentsUnique=NaN*zeros(NumFiles,1);  % the unique flag can be misleading if alot of NaNs
RadialStats.PerDiffFwd=NaN*zeros(NumFiles,1);  % the percentage of NonNan meas that are different from the next time
RadialStats.PerDiffBack=NaN*zeros(NumFiles,1);  % % the percentage of NonNan meas that are different from the previous time
RadialStats.NumRadsInMask=NaN*zeros(NumFiles,1);
RadialStats.NumRadsOutSideMask=NaN*zeros(NumFiles,1);
RadialStats.NumRadsTotal=NaN*zeros(NumFiles,1);
RadialStats.MaxRange=NaN*zeros(NumFiles,1);
RadialStats.MinRange=NaN*zeros(NumFiles,1);
RadialStats.MinBear=NaN*zeros(NumFiles,1);
RadialStats.MaxBear=NaN*zeros(NumFiles,1);
%
%  this loop is redundant, as filenames that do not exist return empty
%  radial structures.  Keep anyway, as it is possible for a filename to
%  exist and no data to be in the file.
%
%  do I need a loop?  - yes, for the check if the files exist
%
for jdeal=1:NumFiles,
    RadialStats.SiteNames{jdeal}=char(Rorig(jdeal).SiteName);
    RadialStats.FileNames{jdeal}=char(Rorig(jdeal).FileName);
end
%
[ts,sites,types]=parseRDLFileName(RadialStats.FileNames);
RadialStats.FileTimeStamp=ts;
%
TemVec=datevec(ts);
%
%  problem!!!! datevec routine sometimes giives 59 minutes and 60 seconds
%  instead of converting to the next hour....  check this.
%
temmark=find((TemVec(:,5)>58)&(TemVec(:,6)>58));
if numel(temmark)>0,
    TemVec(temmark,4)=TemVec(temmark,4)+1;
    TemVec(temmark,5)=0;
    TemVec(temmark,6)=0;
end
%
TemVec=round(TemVec);
%
RadialStats.FileTimes=TemVec;
%
disp('starting basic stat calculation')
%
for jfile=1:NumFiles,
    %  check for Site names
    if numel(Rorig(jfile).SiteName)<1,
        RadialStats.FileFound(jfile)=0;
    else
        RadialStats.FileFound(jfile)=1;
    end
    % check for data
    if sum(isfinite(Rorig(jfile).RadComp))>0,  % change to reflect teh fact that some files can appear to have data
        RadialStats.DataFound(jfile)=1; % so check on issum(finite) instead of isempty  *****  added 27 aug 2007
    else
        RadialStats.DataFound(jfile)=0;
    end
    %  check additional parameters
    if ((RadialStats.FileFound(jfile)>0)&(RadialStats.DataFound(jfile)>0)),
        %  
        %  wobbly radial check  - next routine has errors for unknown
        %  reason
        %
        try
            [rs,bs] = getRangeBearSpacing(Rorig(jfile));
            dd = min( diff( unique( Rorig(jfile).RangeBearHead(:,2) ) ) );
            if isfinite(bs(1)) && isfinite(dd) && bs(1) > dd,
                RadialStats.NotWobblyFiles(jfile) = 0;
            else
                RadialStats.NotWobblyFiles(jfile) = 1;
            end
        catch
            RadialStats.NotWobblyFiles(jfile) = 2;  %%%% means something funny in file
        end
        %
        %  check for time stamp matching
        if abs(RadialStats.FileTimeStamp(jfile)-Rorig(jfile).TimeStamp) > 1/24/10,
            RadialStats.MatchingTimeStamps(jfile)=0;
        else
            RadialStats.MatchingTimeStamps(jfile)=1;
        end
        %  total number of radials
        RadialStats.NumRadsTotal(jfile)=sum(isfinite(Rorig(jfile).RadComp));
        %
    end
end
%
%  Build up the mask file array so that we can pass all of the masking
%  parameters at once
%
%  Use SiteNames in the Rorig array to build up the masking operation.
%  If empty, it does not matter, juust pass any radial file.
%  Could use Sites parameter from the file parsing routine as well, but
%  more flexible to hardcode and use the user passed Sites
%
TotMaskFiles=cell(NumFiles,1);
for jfile=1:numel(TotMaskFiles),
    if numel(RadialMaskFiles)>1,
       temmark=find(ismember(upper(RadialMaskSites),upper(Rorig(jfile).SiteName)));
    else
        temmark=1;
    end
    switch numel(temmark)
        case 0
            %
            %  mask file can be anything
            TotMaskFiles{jfile}=RadialMaskFiles{1};
        case 1
            %
            TotMaskFiles{jfile}=RadialMaskFiles{temmark};
        otherwise
            %
            disp('a problem in assigning mask files')
            disp('routine ending')
            return;
    end
end
%
%  Get range bearing spacing and estimation of limits for the masked
%  radials
%
%  !!!  I can pass maskRdials empty structures, and only get warnings back.
%  Makes this part easy to program.
%
if numel(Rorig)>1,
    [Rmask,II]=maskRadials(Rorig,TotMaskFiles,true);
else
    [Rmask,II]=maskRadials(Rorig,TotMaskFiles{1},true);
end
%
%  Process numrads for masked radials and range/bearing limits
%  parameters
%
disp('starting stat calculation of masked radials')
%
for jfile=1:numel(TotMaskFiles),
    %    numrads
    if ((RadialStats.FileFound(jfile)>0)&(RadialStats.DataFound(jfile)>0)),
        RadialStats.NumRadsInMask(jfile)=sum(isfinite(Rmask(jfile).RadComp));
        RadialStats.NumRadsOutSideMask(jfile)=RadialStats.NumRadsTotal(jfile)-RadialStats.NumRadsInMask(jfile);
    end
    % range bearing limits
    if sum(isfinite(Rmask(jfile).RadComp))>0,
        %
        IndexRadComp=find(isfinite(Rmask(jfile).RadComp));
        %
        RadialStats.MaxRange(jfile)=max(Rmask(jfile).RangeBearHead(IndexRadComp,1));
        RadialStats.MinRange(jfile)=min(Rmask(jfile).RangeBearHead(IndexRadComp,1));
        %
        RadialStats.MaxBear(jfile)=max(Rmask(jfile).RangeBearHead(IndexRadComp,2));
        RadialStats.MinBear(jfile)=min(Rmask(jfile).RangeBearHead(IndexRadComp,2));
        %
    end
    %
end
%
%  temporal concatenation
%
disp('temporal calculation of unmasked files')
%
Rcat = temporalConcatRadials( Rorig, 0.001, 0.49, 0.49, 0.5 );
%
%  empty structures typically end up first in the output.
%  But just in case they don't one time!!!  do as follows
%
FullStruct=NaN*ones(numel(Rcat),1);
%
for jsite=1:numel(Rcat),
    FullStruct(jsite)=double(~isempty(Rcat(jsite).SiteName));
end
%
TemFull=find(FullStruct);
%
Rcat=Rcat(TemFull);
%
%  the radials have been only slightly gridded by the above concatenation procedure
%
%  Step through site by site and check to see that the files at each sucessive time are unique
%  Only compares successive times when we have files...  if time skips,
%  that is not taken into account
%
PerDiffCut=70;  % 70% of the current data have to be different from one another as we step through time.... check RadComp
%
%  use 0.1 cm/s as a limit for sameness - why?  don;t really know, but
%  easy, will prevent roundoff, etc.
%
CutOffCheck=0.1;
%
disp('starting unique calculation of concatenated files')
%
for jsite=1:numel(Rcat),
    %
    TemRad=Rcat(jsite).RadComp;
    [NumPts,NumTimes]=size(TemRad);
    %
    BackDiff=[zeros(NumPts,1) TemRad(:,2:NumTimes)-TemRad(:,1:NumTimes-1)];
    FwdDiff=[TemRad(:,2:NumTimes)-TemRad(:,1:NumTimes-1) zeros(NumPts,1)];
    %
    BackNanMatrix=double(isnan([TemRad(:,1) TemRad(:,1:NumTimes-1)]));
    FwdNanMatrix=double(isnan([TemRad(:,2:NumTimes) TemRad(:,NumTimes)]));
    RadNanMatrix=double(isnan(TemRad));
    %
    %  calculate the differences including NaNs
    %
    BackDiff1=BackDiff;
    FwdDiff1=FwdDiff;
    %
    temmark=find((BackNanMatrix>0.5)&(RadNanMatrix>0.5));  %  means that they are both NaNs, so not different
    %
    if numel(temmark)>0,
        BackDiff1(temmark)=0;  % same value
    end
    %
    temmark=find((BackNanMatrix>0.5)&(RadNanMatrix<0.5));  %  means that they are different
    %
    if numel(temmark)>0,
        BackDiff1(temmark)=10*CutOffCheck;  % any value will do
    end
    %
    temmark=find((BackNanMatrix<0.5)&(RadNanMatrix>0.5));  %  also means that they are different
    %
    if numel(temmark)>0,
        BackDiff1(temmark)=10*CutOffCheck;  % any value will do
    end
    %
    %  last condition (both less than 0.5, or finite) is not necessary to
    %  check
    %
    temmark=find((FwdNanMatrix>0.5)&(RadNanMatrix>0.5));  %  means that they are both NaNs, so not different
    %
    if numel(temmark)>0,
        FwdDiff1(temmark)=0;  % same value
    end
    %
    temmark=find((FwdNanMatrix>0.5)&(RadNanMatrix<0.5));  %  means that they are different
    %
    if numel(temmark)>0,
        FwdDiff1(temmark)=10*CutOffCheck;  % any value will do
    end
    %
    temmark=find((FwdNanMatrix<0.5)&(RadNanMatrix>0.5));  %  also means that they are different
    %
    if numel(temmark)>0,
        FwdDiff1(temmark)=10*CutOffCheck;  % any value will do
    end
    %
    %  at this point, we still have NaNs in BackDiff and FwdDiff, but not
    %  in FwdDiff1 and BackDiff1
    %
    TemmarkSame=find(abs(FwdDiff1)<CutOffCheck);  % which meas are the same (including NaNs)?
    TemmarkDiff=find(abs(FwdDiff1)>=CutOffCheck);
    if numel(TemmarkSame)>0,
        FwdDiff1(TemmarkSame)=0;
    end
    if numel(TemmarkDiff)>0,
        FwdDiff1(TemmarkDiff)=1;
    end
    %
    TemmarkSame=find(abs(BackDiff1)<CutOffCheck);  % which meas are the same (including NaNs)?
    TemmarkDiff=find(abs(BackDiff1)>=CutOffCheck);
    %
    %keyboard
    %
    if numel(TemmarkSame)>0,
        BackDiff1(TemmarkSame)=0;
    end
    if numel(TemmarkDiff)>0,
        BackDiff1(TemmarkDiff)=1;
    end
    %
    TotBackDiff1=sum(BackDiff1);
    TotFwdDiff1=sum(FwdDiff1);
    PerBackDiff1=(100/NumPts)*TotBackDiff1;
    PerFwdDiff1=(100/NumPts)*TotFwdDiff1;
    %
    %  The percentage differences include NaNs
    %  Now repeat for not including NaNs
    %
    %  at this point, we still have NaNs in BackDiff and FwdDiff, but not
    %  in FwdDiff1 and BackDiff1
    %
    TemmarkSame=find(abs(FwdDiff)<CutOffCheck);  % which meas are the same (not including NaNs)?
    TemmarkDiff=find(abs(FwdDiff)>=CutOffCheck);
    if numel(TemmarkSame)>0,
        FwdDiff(TemmarkSame)=0;
    end
    if numel(TemmarkDiff)>0,
        FwdDiff(TemmarkDiff)=1;
    end
    %
    TemmarkSame=find(abs(BackDiff)<CutOffCheck);  % which meas are the same (not including NaNs)?
    TemmarkDiff=find(abs(BackDiff)>=CutOffCheck);
    if numel(TemmarkSame)>0,
        BackDiff(TemmarkSame)=0;
    end
    if numel(TemmarkDiff)>0,
        BackDiff(TemmarkDiff)=1;
    end
    %
    TotBackDiff=nansum(BackDiff);  %  note use of nansum
    TotFwdDiff=nansum(FwdDiff);
    %
    %  number of points used will vary from time to time.  Calculate this.
    %
    FwdFinite=double(isfinite(FwdDiff));
    NumFwdPts=sum(FwdFinite);
    BackFinite=double(isfinite(BackDiff));
    NumBackPts=sum(BackFinite);
    %
    %  check - if numpoints is zero at any time, set to NaN
    %
    %  can't just have one entry, b/c a matrix is returned from the finite
    %  operation, so do not have to check that
    %
    temmark=find(NumFwdPts==0);
    if numel(temmark)>0,
        NumFwdPts(temmark)=NaN;
    end
    temmark=find(NumBackPts==0);
    if numel(temmark)>0,
        NumBackPts(temmark)=NaN;
    end
    %
    PerBackDiff=100*(TotBackDiff./NumBackPts);
    PerFwdDiff=100*(TotFwdDiff./NumFwdPts);
    %
    %  so, PerFwdDiff1 includes NaNs in the count, PerFwdDiff does not
    %
    %
    %  !!!!!  now, the first column of PerBackDiff should be 100, since
    %  there is nothing before the first column to compare to (and given
    %  the logic that follows)
    %
    PerBackDiff(1)=100;
    PerFwdDiff(numel(PerFwdDiff))=100;  % same logic for the end of PerFwdDiff
    %
    PerBackDiff1(1)=100;
    PerFwdDiff1(numel(PerFwdDiff1))=100;  % same logic for the end of PerFwdDiff
    %
    BackFlag=zeros(1,NumTimes);
    FwdFlag=zeros(1,NumTimes);
    %
    BackFlag1=zeros(1,NumTimes);
    FwdFlag1=zeros(1,NumTimes);  
    %
    temmark=find(PerBackDiff<PerDiffCut);
    if numel(temmark)>0,
        BackFlag(temmark)=1;
    end
    %
    temmark=find(PerFwdDiff<PerDiffCut);
    if numel(temmark)>0,
        FwdFlag(temmark)=1;
    end
    %
    temmark=find(PerBackDiff1<PerDiffCut);
    if numel(temmark)>0,
        BackFlag1(temmark)=1;
    end
    %
    temmark=find(PerFwdDiff1<PerDiffCut);
    if numel(temmark)>0,
        FwdFlag1(temmark)=1;
    end
    %
    %
    TotFlag=sign(BackFlag+FwdFlag);  % now is flagged where bad
    TotFlag=double(~TotFlag);  % now flagged where good
    %
    TotFlag1=sign(BackFlag1+FwdFlag1);  % now is flagged where bad
    TotFlag1=double(~TotFlag1);  % now flagged where good   !!!!  this one includes NaNs
    %
    %
    %  now this is a pain, but probably easier in the long run.
    %  go back, loop through, and set the flag to match the original series
    %  that we set
    %
    %  find the file numbers in the original list that
    %  correspond to the SiteCode that we have
    %
    OriginalFileNumbers=find(ismember(RadialStats.SiteNames,Rcat(jsite).SiteName));
    %
    if numel(OriginalFileNumbers)>0,
        %
        OriginalFileTimes=RadialStats.FileTimeStamp(OriginalFileNumbers);
        %
        %
        %  we could check to make sure that all of the above times have data,
        %  but we will only have measurements here for where we did have data,
        %  so no need
        %
        %  times in both cases (Rorig and Rcat) should be sorted, but sort just to make sure
        %  Rcat will be sorted, just not necessary for Rorig or RadialStats to be....
        %  although they typically should be.
        %
        CurrSiteTimes=Rcat(jsite).TimeStamp;
        %
        %  turn into a column array (to match the saved statistics)
        %
        CurrSiteTimes=CurrSiteTimes';
        TotFlag=TotFlag';
        TotFlag1=TotFlag1';
        PerFwdDiff=PerFwdDiff';
        PerBackDiff=PerBackDiff';
        PerFwdDiff1=PerFwdDiff1';
        PerBackDiff1=PerBackDiff1';
        %
        [OriginalFileTimes,IndSort]=sort(OriginalFileTimes,'ascend');
        OriginalFileNumbers=OriginalFileNumbers(IndSort);
        %
        CurrSiteTimes=CurrSiteTimes(IndSort);  % numel of Rorig same as Rcat, empty structures will not return site codes!  
        TotFlag=TotFlag(IndSort);              % Means w do not have to use the intersect function to match up
        TotFlag1=TotFlag1(IndSort);
        PerFwdDiff=PerFwdDiff(IndSort);
        PerBackDiff=PerBackDiff(IndSort);
        PerFwdDiff1=PerFwdDiff1(IndSort);
        PerBackDiff1=PerBackDiff1(IndSort);
        %
        %  now, they have been sorted, they should match, so....
        %
        try
            RadialStats.GriddedCurrentsUnique(OriginalFileNumbers)=TotFlag1;  % sloppy programming, but leave for now
            RadialStats.NonNanGriddedCurrentsUnique(OriginalFileNumbers)=TotFlag;
            RadialStats.PerDiffFwd(OriginalFileNumbers)=PerFwdDiff;
            RadialStats.PerDiffBack(OriginalFileNumbers)=PerBackDiff;
        catch
            disp('some mismatch occured')
            disp('parameters are:')
            jsite
            TotFlag
            OriginalFileNumbers
        end
        %
    end
end
%
return;
%
