function [NewTUV]=InterpTUVToLowResGrid(OldTUV,GridSpacing)
%
%  [NewTUV]=InterpTUVToLowResGrid(OldTUV,GridSpacing);
%
%  Takes high res measurements and djinns up an averaged low res version
%
%  To go from 2km spacing to 10 km, for example.
%
%  a rough interpolation!!!!  just averages all points within a given
%  radius
%
%  TempStats and SpatialStats field stripped from the TUV structure if they
%  exist (actually, just not created).
%
%  ErrorEstimates, OtherSpatialVars, and OtherTemporalVars set to [].
%
%  get the new Grid.
%
%  Step 1 - find the bounding region of the old measurements
%
%  points within 0.6*GridSpacing of the new grid points are used to calculate
%  teh current averages
%
TemStruct.TimeStamp=1;
TemStruct.LonLat=OldTUV.LonLat;
TemStruct.U=ones(numel(OldTUV.LonLat(:,1)),1);
TemStruct.V=ones(numel(OldTUV.LonLat(:,1)),1);
%
[CoverageOut]=FindHFBoundingRegion(TemStruct,1);
%
%  Step 2 - Generate New Grid, and restrict it to the coverage area found
%
[LonOut,LatOut]=LonLat_grid([min(CoverageOut(:,1)) min(CoverageOut(:,2))],[max(CoverageOut(:,1)) max(CoverageOut(:,2))],GridSpacing);
%
LonOut=reshape(LonOut,numel(LonOut),1);
LatOut=reshape(LatOut,numel(LatOut),1);
%
temmark=find(inpolygon(LonOut,LatOut,CoverageOut(:,1),CoverageOut(:,2)));
LonOut=LonOut(temmark,:);
LatOut=LatOut(temmark,:);
%
NumPoints=numel(temmark);
NumTimes=numel(OldTUV.TimeStamp);
%
NewTUV=TUVstruct([NumPoints NumTimes]);
%
NewTUV.DomainName=OldTUV.DomainName;
NewTUV.CreationInfo=OldTUV.CreationInfo;
NewTUV.TimeStamp=OldTUV.TimeStamp;
NewTUV.TimeZone=OldTUV.TimeZone;
NewTUV.CreateTimeZone=OldTUV.CreateTimeZone;
%
NewTUV.LonLat=[LonOut LatOut];
%
%  Step 4 - find the indices of the old points to use to calculate the new
%  data.  Each grid point will have its own list of indices.  This is
%  inefficient, but should work o.k.  And take less memory than doing it all
%  at once.
%
IndexArray=cell(numel(NewTUV.LonLat(:,1)),1);
%
GridFind=0.6*GridSpacing;
%
for jind=1:numel(IndexArray),
    %
    if isequal(rem(jind,100),0),
        disp('finding index array')
        disp([num2str(jind) ' of ' num2str(numel(IndexArray)) ' index array calculations'])
    end
    %
    [s,a12,a21]=m_idist(NewTUV.LonLat(jind,1),NewTUV.LonLat(jind,2),OldTUV.LonLat(:,1),OldTUV.LonLat(:,2),'wgs84');
    %
    %  if positions are too close or the same, m_idist can return NaNs.
    %  Check for this
    %
    temmark=find(isnan(s));
    if numel(temmark)>0,
        AddToLat=0.000000001;
        [s2,a12,a21]=m_idist(NewTUV.LonLat(jind,1),NewTUV.LonLat(jind,2),OldTUV.LonLat(temmark,1),OldTUV.LonLat(temmark,2)+AddToLat,'wgs84');
        s(temmark)=s2;
        clear s2 a12 a21
    end
    %
    s=s/1000;  % now in km
    %
    temmark=find(abs(s)<=GridFind);
    if numel(temmark)>0,
        IndexArray{jind}=[temmark];
    else
        IndexArray{jind}=[];
    end
    %
end
%
%  Step 5 - Fill in the matrix point by point (or "index" by index)
%
for jind=1:numel(IndexArray),
    %
    if numel(IndexArray{jind})>0,
        %
        NewTUV.U(jind,:)=nanmean(OldTUV.U(IndexArray{jind},:));
        NewTUV.V(jind,:)=nanmean(OldTUV.V(IndexArray{jind},:));
        %
    end
end
%
%  the routine is done
%
return;
%
