function InvFirstOrderHFRadialStats(DirIn,FilePrefix,BaseMapLocation)
%
%  InvFirstOrderHFRadialStats(DirIn,FilePrefix,BaseMapLocation);
%
%  CMH, Sept 2007
%
%  This function will look in the directory specified for the files
%  beginning with file prefix, and allow the user to investigate the
%  effects of setting certain statistics flags on the radials.
%  User is prompted interactively for the flags to investigate and the site
%  to investigate.
%
%  One tricky part of writing this program is that the radials and
%  statistics gave been saved in groups of files, so that it is possible that
%  not all files will contain flags that will be set by certain specified error levels.
%  The files are read in, the file numbers with flags are found, and the user
%  is prompted for which one to load and display.
%
%  Assumes that each file has saved two structures - Rorig and RadialStats.
%
%  !!  Does not actually key off of time
%
%  If alot of files, could be memory issues.  May want to spilt files into separate 
%  directories first if that happens.  Could rewrite to not have this
%  happen, but routine would get alot slower than it is....  or could
%  prompt user for which numbers of files to investigate.
%
scrsz = get(0,'ScreenSize');  % will be used to place figures
%
load(BaseMapLocation)
LonLim=[nanmin(ncst(:,1)) nanmax(ncst(:,1))];
LatLim=[nanmin(ncst(:,2)) nanmax(ncst(:,2))];
clear Area k ncst
%
cd(DirIn);
%
SizeFilePrefix=numel(FilePrefix);
TemDir=dir;
IsOldFile=zeros(numel(TemDir),1);
for jdir=1:numel(TemDir),
    if isequal(TemDir(jdir).isdir,0),
        if numel(TemDir(jdir).name)>(SizeFilePrefix+3),
            TemName=TemDir(jdir).name;
            if isequal(TemName(1:SizeFilePrefix),FilePrefix),
                if isequal(TemName(numel(TemName)-3:numel(TemName)),'.mat'),
                    IsOldFile(jdir)=1;
                end
            end
        end
    end
end
%
if sum(IsOldFile)>0,
    temmark=find(IsOldFile>0);
    IsOldFile=temmark;
    TemDir=TemDir(temmark);
    NumOldFiles=numel(IsOldFile);
else
    disp('no old radial files found')
    disp('routine ending')
    return;
end
%
%  We now have the names of the old files containing radials in the
%  directory.
%
%  Load the first file, set up the fields recorded by RadialStats
%
load(TemDir(1).name);
%
StatNames=fieldnames(RadialStats);
%
clear Rorig RadialStats
%
%   Choose which error to investigate (prompt the user)
%
NumErrorsIncluded=numel(StatNames);
%
[Selection,OK]=listdlg('PromptString','Select An Error Method:','SelectionMode','single',...
    'ListString',StatNames);
%
if ~OK,
    disp('no error selection method chosen')
    disp('routine will end')
    ErrReturn='None';
    return;
end
%
ErrReturn=StatNames{Selection};
%
if (isequal(ErrReturn,'PerDiffFwd')||isequal(ErrReturn,'PerDiffBack')),
    %
    InvBoth=questdlg(['You chose to investigate' ErrReturn],'Choice','Ok','Ok','Ok'); 
    InvBoth=questdlg('Do you wish to investigate using both percent differences (fwd and back)?','Use Both?','Yes','No','Yes');  % change to while loop?
    switch InvBoth
        case 'Yes'
            ErrReturn='PerDiffFwd';
            ErrReturn2='PerDiffBack';
        case 'No'
            %
            %  do nothing
    end
end
%
%  This is a bit redundant, but will allow some files to have radials from all sites, some
%  to only have radials from one site, etc.
%
%  First loop, load files and find out how many sites we have
%
for jdir=1:numel(TemDir),
    load(TemDir(jdir).name);
    [TemSite{1:numel(Rorig)}]=deal(Rorig.SiteName);
    TemSite=unique(TemSite);
    if jdir>1,
        TemSiteAll=[TemSiteAll TemSite];  % assumes stats are saved in format we specified
        TemSiteAll=unique(TemSiteAll);
    else
        TemSiteAll=TemSite;
    end
    clear TemSite Rorig RadialStats
end
%
temmark=find(~ismember(TemSiteAll,''));  % only keep nonempty sites
if numel(temmark)>=1,
    TemSiteAll=TemSiteAll(temmark);
else
    disp('no sites with valid data found in directory')
    disp('routine is ending')
    return;
end
%
%  Now loop, find stats of parameters that the user wished to investigate, display on the screen
%
%  get the stats for each site separately
%
Err1.SiteName=NaN;
Err1.StartTime=NaN;
Err1.EndTime=NaN;
Err1.PercentNaNs=NaN;
Err1.TotNaNs=NaN;
Err1.TotMeas=NaN;
Err1.MinVal=NaN;
Err1.MaxVal=NaN;
%
ErrAll1(1:numel(TemSiteAll))=deal(Err1);
ErrAll2(1:numel(TemSiteAll))=deal(Err1);  % in case the user has chosen to use the other percent diff as well
%
clear Err1
%
Stat1.SiteName=NaN;
Stat1.Ser=NaN;
Stat1.CheckedNumInFile=NaN;
Stat1.FileNum=NaN;
Stat1.RadTime=NaN;
%
StatSum1(1:numel(TemSiteAll))=deal(Stat1);
StatSum2(1:numel(TemSiteAll))=deal(Stat1);
%
clear Stat1
%
for jsite=1:numel(TemSiteAll),
    ErrAll1(jsite).SiteName=char(TemSiteAll{jsite});
    StatSum1(jsite).SiteName=char(TemSiteAll{jsite});
    if exist('ErrReturn2','var'),
        ErrAll2(jsite).SiteName=char(TemSiteAll{jsite});
        StatSum2(jsite).SiteName=char(TemSiteAll{jsite});
    end
end
%
disp('loading and processing stats')
disp('please be patient')
pause(2);
%
for jdir=1:numel(TemDir),
    load(TemDir(jdir).name);
    [TemSite{1:numel(Rorig)}]=deal(Rorig.SiteName);
    for jsite=1:numel(TemSiteAll),
        temmark=find(ismember(TemSite,TemSiteAll(jsite)));
        if numel(temmark)>0,  % no data found not taken into account here, so add it (temmark2, below)
            RorigSub=Rorig(temmark);
            [RadialStatsSub]=ExtractFieldsFromStruct(RadialStats,temmark);
            TemTime=[RorigSub(1:numel(RorigSub)).TimeStamp];
            temmark2=find(~isnan(TemTime));
            if numel(temmark2)>0,
                RorigSub=RorigSub(temmark2);
                [RadialStatsSub]=ExtractFieldsFromStruct(RadialStatsSub,temmark2);
                TemTime=[RorigSub(1:numel(RorigSub)).TimeStamp];
                eval(['TemSer=RadialStatsSub.' ErrReturn ';']);
                ErrAll1(jsite).MinVal=nanmin([ErrAll1(jsite).MinVal nanmin(TemSer)]);
                ErrAll1(jsite).MaxVal=nanmax([ErrAll1(jsite).MaxVal nanmax(TemSer)]);
                ErrAll1(jsite).StartTime=nanmin([ErrAll1(jsite).StartTime nanmin(TemTime)]);
                ErrAll1(jsite).EndTime=nanmin([ErrAll1(jsite).EndTime nanmax(TemTime)]);
                ErrAll1(jsite).TotMeas=nansum([ErrAll1(jsite).TotMeas numel(TemTime)]);
                ErrAll1(jsite).TotNaNs=nansum([ErrAll1(jsite).TotNaNs sum(isnan(TemSer))]);
                %
                StatSum1(jsite).Ser=[StatSum1(jsite).Ser;TemSer];
                TemInd=1:numel(TemSer);
                TemInd=TemInd';
                StatSum1(jsite).CheckedNumInFile=[StatSum1(jsite).CheckedNumInFile;TemInd];
                StatSum1(jsite).FileNum=[StatSum1(jsite).FileNum;jdir*ones(size(TemInd))];
                StatSum1(jsite).RadTime=[StatSum1(jsite).RadTime TemTime];
                %
                if exist('ErrReturn2','var'),
                    eval(['TemSer=RadialStatsSub.' ErrReturn2 ';']);
                    ErrAll2(jsite).MinVal=nanmin([ErrAll2(jsite).MinVal nanmin(TemSer)]);
                    ErrAll2(jsite).MaxVal=nanmax([ErrAll2(jsite).MaxVal nanmax(TemSer)]);
                    ErrAll2(jsite).StartTime=nanmin([ErrAll2(jsite).StartTime nanmin(TemTime)]);
                    ErrAll2(jsite).EndTime=nanmin([ErrAll2(jsite).EndTime nanmax(TemTime)]);
                    ErrAll2(jsite).TotMeas=nansum([ErrAll2(jsite).TotMeas numel(TemTime)]);
                    ErrAll2(jsite).TotNaNs=nansum([ErrAll2(jsite).TotNaNs sum(isnan(TemSer))]);
                    %
                    StatSum2(jsite).Ser=[StatSum2(jsite).Ser;TemSer];
                    TemInd=1:numel(TemSer);
                    TemInd=TemInd';
                    StatSum2(jsite).CheckedNumInFile=[StatSum2(jsite).CheckedNumInFile;TemInd];
                    StatSum2(jsite).FileNum=[StatSum2(jsite).FileNum;jdir*ones(size(TemInd))];
                    StatSum2(jsite).RadTime=[StatSum2(jsite).RadTime TemTime];
                    %
                end
            end
        end
    end
    %
    clear TemSite Rorig RadialStats
    %
end
%
%  remove the first entry from the StatSum variables, was set to NaN
%  deliberately
%
for jsite=1:numel(TemSiteAll),
    TemSer=StatSum1(jsite).Ser;
    if numel(TemSer)>1,
        StatSum1(jsite).Ser=TemSer(2:numel(TemSer));
        TemSer=StatSum1(jsite).CheckedNumInFile;
        StatSum1(jsite).CheckedNumInFile=TemSer(2:numel(TemSer));
        TemSer=StatSum1(jsite).FileNum;
        StatSum1(jsite).FileNum=TemSer(2:numel(TemSer));
        TemSer=StatSum1(jsite).RadTime;
        StatSum1(jsite).RadTime=TemSer(2:numel(TemSer));
    end
    if exist('ErrReturn2','var'),
        TemSer=StatSum2(jsite).Ser;
        if numel(TemSer)>1,
            StatSum2(jsite).Ser=TemSer(2:numel(TemSer));
            TemSer=StatSum2(jsite).CheckedNumInFile;
            StatSum2(jsite).CheckedNumInFile=TemSer(2:numel(TemSer));
            TemSer=StatSum2(jsite).FileNum;
            StatSum2(jsite).FileNum=TemSer(2:numel(TemSer));
            TemSer=StatSum2(jsite).RadTime;
            StatSum2(jsite).RadTime=TemSer(2:numel(TemSer));
        end
    end
end
%
%  Now sort by time.  There was no guarantee that the files were loaded in
%  the correct time order.
%
%  both of the time matrices for StatSum1 and StatSum2 were set to the same
%  value.
%
for jsite=1:numel(TemSiteAll),
    [TemTime,IndSort]=sort(StatSum1(jsite).RadTime,'ascend');
    StatSum1(jsite).Ser=StatSum1(jsite).Ser(IndSort);
    StatSum1(jsite).CheckedNumInFile=StatSum1(jsite).CheckedNumInFile(IndSort);
    StatSum1(jsite).FileNum=StatSum1(jsite).FileNum(IndSort);
    StatSum1(jsite).RadTime=StatSum1(jsite).RadTime(IndSort);
    if exist('ErrReturn2','var'),
        [TemTime,IndSort]=sort(StatSum2(jsite).RadTime,'ascend');
        StatSum2(jsite).Ser=StatSum2(jsite).Ser(IndSort);
        StatSum2(jsite).CheckedNumInFile=StatSum2(jsite).CheckedNumInFile(IndSort);
        StatSum2(jsite).FileNum=StatSum2(jsite).FileNum(IndSort);
        StatSum2(jsite).RadTime=StatSum2(jsite).RadTime(IndSort);
    end
end
%
for jsite=1:numel(TemSiteAll),
    ErrAll1(jsite).PercentNaNs=100*(ErrAll1(jsite).TotNaNs/ErrAll1(jsite).TotMeas);
    if exist('ErrReturn2','var'),
        ErrAll2(jsite).PercentNaNs=100*(ErrAll2(jsite).TotNaNs/ErrAll2(jsite).TotMeas);
    end
end
%
CheckAgain=1;
%
TemSitePrompt=cell(numel(TemSiteAll)+1,1);
for jsite=1:numel(TemSiteAll),
    TemSitePrompt(jsite)=TemSiteAll(jsite);
end
TemSitePrompt(numel(TemSiteAll)+1)={'None'};
%
while CheckAgain,
    %
    [Selection,OK]=listdlg('PromptString','Select Next Site To Check','SelectionMode','single',...
    'ListString',TemSitePrompt);
    if ((~OK)||(Selection==numel(TemSiteAll)+1)),
        CheckAgain=0;
        disp('No site selected. Routine ending.')
        return;
    else
        SiteToCheck=TemSiteAll{Selection};
        SiteNum=Selection;
        TemVecStart=datevec(ErrAll1(SiteNum).StartTime);
        TemVecEnd=datevec(ErrAll1(SiteNum).EndTime);
        ListTem={'TimeStart';['  Month ' num2str(TemVecStart(2))];['  Day ' num2str(TemVecStart(3))];['  Hour ' num2str(TemVecStart(4))];...
            ['  Year ' num2str(TemVecStart(1))];'TimeEnd';['  Month ' num2str(TemVecEnd(2))];['  Day ' num2str(TemVecEnd(3))];...
            ['  Hour ' num2str(TemVecEnd(4))];['  Year ' num2str(TemVecEnd(1))];['TotMeas: ' num2str(ErrAll1(SiteNum).TotMeas)];...
            ['PercentNanStat: ' num2str(ErrAll1(SiteNum).PercentNaNs)];['MINVAL: ' num2str(ErrAll1(SiteNum).MinVal)];...
            ['MAXVAL: ' num2str(ErrAll1(SiteNum).MaxVal)]};
        TemName=['Just Info, Parameter: ' ErrReturn ' Site: ' char(SiteToCheck)];
        [Selection,OK]=listdlg('PromptString',TemName,'SelectionMode','single',...
        'ListString',ListTem);
        %
        if ~OK,
            CheckAgain=0;
        end
        %
        if exist('ErrReturn2','var'),
            TemVecStart=datevec(ErrAll2(SiteNum).StartTime);
            TemVecEnd=datevec(ErrAll2(SiteNum).EndTime);
            ListTem={'TimeStart';['  Month ' num2str(TemVecStart(2))];['  Day ' num2str(TemVecStart(3))];['  Hour ' num2str(TemVecStart(4))];...
                ['  Year ' num2str(TemVecStart(1))];'TimeEnd';['  Month ' num2str(TemVecEnd(2))];['  Day ' num2str(TemVecEnd(3))];...
                ['  Hour ' num2str(TemVecEnd(4))];['  Year ' num2str(TemVecEnd(1))];['TotMeas: ' num2str(ErrAll2(SiteNum).TotMeas)];...
                ['PercentNanStat: ' num2str(ErrAll2(SiteNum).PercentNaNs)];['MINVAL: ' num2str(ErrAll2(SiteNum).MinVal)];...
                ['MAXVAL: ' num2str(ErrAll2(SiteNum).MaxVal)]};
            TemName=['Just Info, Parameter: ' ErrReturn2 ' Site: ' char(SiteToCheck)];
            [Selection,OK]=listdlg('PromptString',TemName,'SelectionMode','single',...
            'ListString',ListTem);
            %
            if ~OK,
                CheckAgain=0;
            end
        end
        %
        if CheckAgain,
            %
            prompt={'MinVal To Use:';'MaxVal To Use:'};
            name=['Set GOOD ' ErrReturn ' Bounds, measured bounds shown:'];
            numlines=1;
            defaultanswer={[num2str(ErrAll1(SiteNum).MinVal)];[num2str(ErrAll1(SiteNum).MaxVal)]};
            options.Resize='on';
            options.WindowStyle='modal';
            options.Interpreter='none';
            xlimitscell=inputdlg(prompt,name,numlines,defaultanswer,options);
            ErrBounds1=[str2num(char(xlimitscell{1}));str2num(char(xlimitscell{2}))];
            clear xlimitscell
            %
            if exist('ErrReturn2','var'),
                name=['Set GOOD ' ErrReturn2 ' Bounds, measured bounds shown:'];
                defaultanswer={[num2str(ErrAll2(SiteNum).MinVal)];[num2str(ErrAll2(SiteNum).MaxVal)]};
                options.Resize='on';
                options.WindowStyle='modal';
                options.Interpreter='none';
                xlimitscell=inputdlg(prompt,name,numlines,defaultanswer,options);
                ErrBounds2=[str2num(char(xlimitscell{1}));str2num(char(xlimitscell{2}))];
                clear xlimitscell
            end
            %
            %  continue with processing
            %
            %  Find which sets of radials are "good" according to the criteria
            %  selected, and which are "bad"
            %
            TemBad1=find((StatSum1(SiteNum).Ser<ErrBounds1(1))|(StatSum1(SiteNum).Ser>ErrBounds1(2)));
            TemGood1=find((StatSum1(SiteNum).Ser>=ErrBounds1(1))&(StatSum1(SiteNum).Ser<=ErrBounds1(2)));
            %
            if exist('ErrReturn2','var'),
                TemBad2=find((StatSum2(SiteNum).Ser<ErrBounds2(1))|(StatSum2(SiteNum).Ser>ErrBounds2(2)));
                TemGood2=find((StatSum2(SiteNum).Ser>=ErrBounds2(1))&(StatSum2(SiteNum).Ser<=ErrBounds2(2)));
                TemBadAll=intersect(TemBad1,TemBad2);
                TemGoodAddition=setxor(TemBad1,TemBad2);
                TemGood1=union(TemGood1,TemGood2);
                TemGood1=union(TemGood1,TemGoodAddition);
                TemBad1=TemBadAll;
                clear TemBad2 TemGood2 TemBadAll TemGoodAddition
            end
            %
            %  note: if ErrReturn2 exists, it is possible that one stat
            %  value is set to NaN while the other is defined, could have
            %  gotten into the "good" radial defnition.  Not too likely,
            %  but possible.
            %
            TemStr=['Num "Bad" Radial Sets: ' num2str(numel(TemBad1))];
            InfoOnly=questdlg(TemStr,'Radials Flagged As Bad','Ok','Ok','Ok');
            TemStr=['Num "Good" Radial Sets: ' num2str(numel(TemGood1))];
            InfoOnly=questdlg(TemStr,'Radials Flagged As Good','Ok','Ok','Ok');
            %
            if numel(TemBad1)>=1,
                %
                name=['Radial Set To Use?'];
                defaultanswer={'1'};
                numlines=1';
                prompt={'Enter (bad) Radial Set Number: '};
                xlimitscell=inputdlg(prompt,name,numlines,defaultanswer);
                RadialSetToUse=[str2num(char(xlimitscell{1}))];
                clear xlimitscell
                %
                %  load the appropriate file
                %
                TemName=TemDir(StatSum1(SiteNum).FileNum(TemBad1(RadialSetToUse))).name;
                load(TemName);
                [TemSite{1:numel(Rorig)}]=deal(Rorig.SiteName);
                temmark=find(ismember(TemSite,TemSiteAll(SiteNum)));
                if numel(temmark)>0,  % no data found not taken into account here, so add it (temmark2, below)
                    RorigSub=Rorig(temmark);
                    [RadialStatsSub]=ExtractFieldsFromStruct(RadialStats,temmark);
                    TemTime=[RorigSub(1:numel(RorigSub)).TimeStamp];
                    temmark2=find(~isnan(TemTime));
                    if numel(temmark2)>0,
                        RorigSub=RorigSub(temmark2);
                        [RadialStatsSub]=ExtractFieldsFromStruct(RadialStatsSub,temmark2);
                        RorigBad=RorigSub(StatSum1(SiteNum).CheckedNumInFile(TemBad1(RadialSetToUse)));
                        RadStatsBad=ExtractFieldsFromStruct(RadialStatsSub,StatSum1(SiteNum).CheckedNumInFile(TemBad1(RadialSetToUse)));
                    end
                end
                clear Rorig TemSite RadialStats
                %
                %  load the closest good radial set before this one
                %
                TemSer=find(TemGood1<TemBad1(RadialSetToUse));
                if numel(TemSer>0),
                    IndGood=TemGood1(TemSer(numel(TemSer)));
                    TemName=TemDir(StatSum1(SiteNum).FileNum(IndGood)).name;
                    load(TemName);
                    [TemSite{1:numel(Rorig)}]=deal(Rorig.SiteName);
                    temmark=find(ismember(TemSite,TemSiteAll(SiteNum)));
                    if numel(temmark)>0,  % no data found not taken into account here, so add it (temmark2, below)
                        RorigSub=Rorig(temmark);
                        [RadialStatsSub]=ExtractFieldsFromStruct(RadialStats,temmark);
                        TemTime=[RorigSub(1:numel(RorigSub)).TimeStamp];
                        temmark2=find(~isnan(TemTime));
                        if numel(temmark2)>0,
                            RorigSub=RorigSub(temmark2);
                            [RadialStatsSub]=ExtractFieldsFromStruct(RadialStatsSub,temmark2);
                            RorigGoodBefore=RorigSub(StatSum1(SiteNum).CheckedNumInFile(IndGood));
                            RadStatsGoodBefore=ExtractFieldsFromStruct(RadialStatsSub,StatSum1(SiteNum).CheckedNumInFile(IndGood));
                        end
                    end
                    clear Rorig TemSite RadialStats
                end
                %
                %  load the closest good radial data set after this one
                %
                TemSer=find(TemGood1>TemBad1(RadialSetToUse));
                if numel(TemSer)>0,
                    IndGood=TemGood1(TemSer(1));
                    TemName=TemDir(StatSum1(SiteNum).FileNum(IndGood)).name;
                    load(TemName);
                    [TemSite{1:numel(Rorig)}]=deal(Rorig.SiteName);
                    temmark=find(ismember(TemSite,TemSiteAll(SiteNum)));
                    if numel(temmark)>0,  % no data found not taken into account here, so add it (temmark2, below)
                        RorigSub=Rorig(temmark);
                        [RadialStatsSub]=ExtractFieldsFromStruct(RadialStats,temmark);
                        TemTime=[RorigSub(1:numel(RorigSub)).TimeStamp];
                        temmark2=find(~isnan(TemTime));
                        if numel(temmark2)>0,
                            RorigSub=RorigSub(temmark2);
                            [RadialStatsSub]=ExtractFieldsFromStruct(RadialStatsSub,temmark2);
                            RorigGoodAfter=RorigSub(StatSum1(SiteNum).CheckedNumInFile(IndGood));
                            RadStatsGoodAfter=ExtractFieldsFromStruct(RadialStatsSub,StatSum1(SiteNum).CheckedNumInFile(IndGood));
                        end
                    end
                    clear Rorig TemSite RadialStats
                end
                %
                %  now get info. to plot
                %
                BadPlotTitle=[datestr(datevec(RorigBad.TimeStamp))];
                if exist('RorigGoodBefore','var'),
                    GoodBeforePlotTitle=[datestr(datevec(RorigGoodBefore.TimeStamp))];
                end
                if exist('RorigGoodAfter','var'),
                   GoodAfterPlotTitle=[datestr(datevec(RorigGoodAfter.TimeStamp))];
                end
                %
                eval(['TemBadStr=RadStatsBad.' ErrReturn ';'])
                if exist('RorigGoodBefore','var'),
                    eval(['TemGoodBeforeStr=RadStatsGoodBefore.' ErrReturn ';'])
                end
                if exist('RorigGoodAfter','var'),
                    eval(['TemGoodAfterStr=RadStatsGoodAfter.' ErrReturn ';'])
                end
                %
                TemBadStr=[' Parameter 1: ' num2str(TemBadStr)];
                if exist('RorigGoodBefore','var'),
                    TemGoodBeforeStr=[' Parameter 1: ' num2str(TemGoodBeforeStr)];
                end
                if exist('RorigGoodAfter','var'),
                    TemGoodAfterStr=[' Parameter 1: ' num2str(TemGoodAfterStr)];
                end
                %
                if exist('ErrReturn2','var'),
                    eval(['TemParmStr=RadStatsBad.' ErrReturn2 ';'])
                    TemBadStr=[TemBadStr ' Param. 2: ' num2str(TemParmStr)];
                    if exist('RorigGoodBefore','var'),
                        eval(['TemParmStr=RadStatsGoodBefore.' ErrReturn2 ';'])
                        TemGoodBeforeStr=[TemGoodBeforeStr ' Param. 2: ' num2str(TemParmStr)];
                    end
                    if exist('RorigGoodAfter','var'),
                        eval(['TemParmStr=RadStatsGoodAfter.' ErrReturn2 ';'])
                        TemGoodAfterStr=[TemGoodAfterStr ' Param. 2: ' num2str(TemParmStr)];
                    end
                end
                %
                TemFig1=figure('Position',[1 0.6*scrsz(4) scrsz(3)/2 0.4*scrsz(4)]);
                TemFig2=figure('Position',[scrsz(3)/2 0.6*scrsz(4) scrsz(3)/2 0.4*scrsz(4)]);
                TemFig3=figure('Position',[1 1 scrsz(3)/2 0.4*scrsz(4)]);
                TemFig4=figure('Position',[scrsz(3)/2 1 scrsz(3)/2 0.4*scrsz(4)]);
                %
                %  the data before the "bad" data
                %
                figure(TemFig1);
                if exist('RorigGoodBefore','var'),
                    ScaleTheVectors=0.01;
                    CLimTem=[0 100];
                    plotBasemap(LonLim,LatLim,BaseMapLocation,'lambert', 'patch', [0.5 0.5 0.5] );
                    hold
                    [handles,TimeIndex]=plotData(RorigGoodBefore,'m_vec',1,ScaleTheVectors);
                    xlabel('longitude')
                    ylabel('latitude')
                    title(['Good Data Before ' GoodBeforePlotTitle TemGoodBeforeStr]);
                    caxis(CLimTem)
                    CheckScaleAgain=1;
                    while CheckScaleAgain,
                        ScaleOK=questdlg(['Are the vectors scaled ok?'],'Scale?','Yes','No','Yes');
                        switch upper(ScaleOK)
                            case 'YES'
                                CheckScaleAgain=0;
                            case 'NO'
                                name=['Scale To Use?'];
                                defaultanswer={[num2str(ScaleTheVectors)]};
                                numlines=1;
                                prompt={'Enter Scaling Value: '};
                                xlimitscell=inputdlg(prompt,name,numlines,defaultanswer);
                                ScaleTheVectors=[str2num(char(xlimitscell{1}))];
                                clear xlimitscell
                                %
                                delete(TemFig1);
                                TemFig1=figure('Position',[1 0.6*scrsz(4) scrsz(3)/2 0.4*scrsz(4)]);
                                plotBasemap(LonLim,LatLim,BaseMapLocation,'lambert', 'patch', [0.5 0.5 0.5] );
                                hold
                                [handles,TimeIndex]=plotData(RorigGoodBefore,'m_vec',1,ScaleTheVectors);
                                xlabel('longitude')
                                ylabel('latitude')
                                title(['Good Data Before ' GoodBeforePlotTitle TemGoodBeforeStr]);
                                %
                        end
                    end
                    CheckColorAgain=1;
                    while CheckColorAgain,
                        ColorOK=questdlg(['Is the colormap limit ok?'],'Color?','Yes','No','Yes');
                        switch upper(ColorOK)
                            case 'YES'
                                CheckColorAgain=0;
                            case 'NO'
                                name=['Color Scale To Use?'];
                                defaultanswer={[num2str(CLimTem(1))];[num2str(CLimTem(2))]};
                                numlines=1;
                                prompt={'Enter Min Val: ';'Enter Max Val: '};
                                xlimitscell=inputdlg(prompt,name,numlines,defaultanswer);
                                CLimTem=[str2num(char(xlimitscell{1})) str2num(char(xlimitscell{2}))];
                                clear xlimitscell
                                %
                                caxis(CLimTem);
                                %
                        end
                    end
                else
                    plot(0,0)
                    hold
                    text(1,1,'no good data before')
                    set(gca,'XLim',[0 5])
                    set(gca,'YLim',[0 2])
                end
                %
                %  the "bad" data
                %
                figure(TemFig2);
                if exist('ScaleTheVectors','var'),
                    plotBasemap(LonLim,LatLim,BaseMapLocation,'lambert', 'patch', [0.5 0.5 0.5] );
                    hold
                    [handles,TimeIndex]=plotData(RorigBad,'m_vec',1,ScaleTheVectors);
                    xlabel('longitude')
                    ylabel('latitude')
                    title(['Flagged Data ' BadPlotTitle TemBadStr]);
                    caxis(CLimTem);
                else
                    ScaleTheVectors=0.01;
                    CLimTem=[0 100];
                    plotBasemap(LonLim,LatLim,BaseMapLocation,'lambert', 'patch', [0.5 0.5 0.5] );
                    hold
                    [handles,TimeIndex]=plotData(RorigBad,'m_vec',1,ScaleTheVectors);
                    xlabel('longitude')
                    ylabel('latitude')
                    title(['Flagged Data ' BadPlotTitle TemBadStr]);
                    CheckScaleAgain=1;
                    while CheckScaleAgain,
                        ScaleOK=questdlg(['Are the vectors scaled ok?'],'Scale?','Yes','No','Yes');
                        switch upper(ScaleOK)
                            case 'YES'
                                CheckScaleAgain=0;
                            case 'NO'
                                name=['Scale To Use?'];
                                defaultanswer={[num2str(ScaleTheVectors)]};
                                numlines=1;
                                prompt={'Enter Scaling Value: '};
                                xlimitscell=inputdlg(prompt,name,numlines,defaultanswer);
                                ScaleTheVectors=[str2num(char(xlimitscell{1}))];
                                clear xlimitscell
                                %
                                delete(TemFig2);
                                TemFig2=figure('Position',[scrsz(3)/2 0.6*scrsz(4) scrsz(3)/2 0.4*scrsz(4)]);
                                plotBasemap(LonLim,LatLim,BaseMapLocation,'lambert', 'patch', [0.5 0.5 0.5] );
                                hold
                                [handles,TimeIndex]=plotData(RorigBad,'m_vec',1,ScaleTheVectors);
                                xlabel('longitude')
                                ylabel('latitude')
                                title(['Flagged Data ' BadPlotTitle TemBadStr]);
                                %
                        end
                    end
                    CheckColorAgain=1;
                    while CheckColorAgain,
                        ColorOK=questdlg(['Is the colormap limit ok?'],'Color?','Yes','No','Yes');
                        switch upper(ColorOK)
                            case 'YES'
                                CheckColorAgain=0;
                            case 'NO'
                                name=['Color Scale To Use?'];
                                defaultanswer={[num2str(CLimTem(1))];[num2str(CLimTem(2))]};
                                numlines=1;
                                prompt={'Enter Min Val: ';'Enter Max Val: '};
                                xlimitscell=inputdlg(prompt,name,numlines,defaultanswer);
                                CLimTem=[str2num(char(xlimitscell{1})) str2num(char(xlimitscell{2}))];
                                clear xlimitscell
                                %
                                caxis(CLimTem);
                                %
                        end
                    end
                end
                %
                %  the "bad" data, repeated
                %
                figure(TemFig3);
                plotBasemap(LonLim,LatLim,BaseMapLocation,'lambert', 'patch', [0.5 0.5 0.5] );
                hold
                [handles,TimeIndex]=plotData(RorigBad,'m_vec',1,ScaleTheVectors);
                xlabel('longitude')
                ylabel('latitude')
                title(['Flagged Data ' BadPlotTitle TemBadStr]);
                caxis(CLimTem);
                %
                %  the "good after" data
                %
                figure(TemFig4);
                if exist('RorigGoodAfter','var'),
                    plotBasemap(LonLim,LatLim,BaseMapLocation,'lambert', 'patch', [0.5 0.5 0.5] );
                    hold
                    [handles,TimeIndex]=plotData(RorigGoodAfter,'m_vec',1,ScaleTheVectors);
                    xlabel('longitude')
                    ylabel('latitude')
                    title(['Good Data After ' GoodAfterPlotTitle TemGoodAfterStr]);
                    caxis(CLimTem);
                else
                    plot(0,0)
                    hold
                    text(1,1,'no good data after')
                    set(gca,'XLim',[0 5])
                    set(gca,'YLim',[0 2])
                end
                %
                %
                InfoOnly=questdlg(['Click OK When Done Viewing'],'View','Ok','Ok','Ok');
                %
                delete(TemFig1);
                delete(TemFig2);
                delete(TemFig3);
                delete(TemFig4);
                %
                clear RorigBad RadStatsBad
                clear RorigGoodAfter RadStatsGoodAfter
                clear RorigGoodBefore RadStatsBadAfter
                clear ScaleTheVectors CLimTem
                %
            else
                %
                disp('no bad radials found')
                pause(2);
            end
        end
    end
end
%
%
%  the routine is done
%
return;
