function ObtainVariousSatelliteData(DirOut,LonLims,LatLims,DateStart,DateEnd,DataType)
%
%
%  ObtainVariousSatelliteData(DirOut,LonLimits,LatLimits,DateStart,DateEnd,DataType);
%
%  To get various satellite data sets.....  from CoastWatch...... will step through in chunks and pause, and redo several times 
%  to try and ensure that we get all of the data.  (b/c of Matlab and the network, we often don't
%  get the data we need after a certain point)
%
%  DateStart and DateEnd is [YYYY MM DD]
%
%  Run this several times to make sure.
%
%  See below for valid values for DataType
%
%  Added Quickscat science quality winds, 1 day, b/c the blended product is
%  no longer supported!  CMH 27 April 2010
%
if ~exist(DirOut,'dir'),
    [SUCCESS,MESSAGE,MESSAGEID]=mkdir(DirOut);
    if ~SUCCESS,
        disp('could not create the output directory')
        disp('routine ending')
        return;
    end
end
%
RunTimeLogFile=['LogRunTime' datestr(now,30) '.txt'];  % check this syntax
DataCheckLogFile=['LogDataCheck' datestr(now,30) '.txt'];  % check this syntax
%
switch upper(DataType)
    case 'AVHRRSST3DAY'
        DataSet='TATssta';
        AverageTtype='3day';
        ParamVarName='ATssta';
        FirstFilePartName='SST3Day';
        HourStamp='12';
    case 'AQUACHL3DAY'
        DataSet='TMYchla';
        AverageTtype='3day';
        ParamVarName='MYchla';
        FirstFilePartName='CHL3Day';
        HourStamp='12';
    case 'EXPAQUACHL3DAY'  % sensor on a different satellite?
        DataSet='TMWchla';
        AverageTtype='3day';
        ParamVarName='MWchla';
        FirstFilePartName='EXPCHL3Day';
        HourStamp='12';
    case 'BLENDEDSST5DAY'
        DataSet='TBAssta';
        AverageTtype='5day';
        ParamVarName='BAssta';
        FirstFilePartName='BLNDSST5Day';
        HourStamp='12';
    case 'GOESSST3DAY'
        DataSet='TGAssta';
        AverageTtype='3day';
        ParamVarName='GAssta';
        FirstFilePartName='GOESSST3Day';
        HourStamp='12';
    case 'ZONALBLENDEDWIND1DAY'
        DataSet='TNWuuuu';
        AverageTtype='1day';
        ParamVarName='NWuuuu';
        FirstFilePartName='BLNDZONWIND1Day';
        HourStamp='09';
    case 'MERIDIONALBLENDEDWIND1DAY'
        DataSet='TNWvvvv';
        AverageTtype='1day';
        ParamVarName='NWvvvv';
        FirstFilePartName='BLNDMERWIND1Day';
        HourStamp='09';
    case 'ZONALQSCATWINDS1DAY'
        %  this is real time version
        DataSet='TQNux10';
        AverageTtype='1day';
        ParamVarName='QNux10';
        FirstFilePartName='QSCATZONWIND1Day';
        HourStamp='12';
    case 'MERIDIONALQSCATWINDS1DAY'
        % this is the real time version
        DataSet='TQNuy10';
        AverageTtype='1day';
        ParamVarName='QNuy10';
        FirstFilePartName='QSCATMERWIND1Day';
        HourStamp='12';
    case 'ZONALQSCATWINDS1DAYSCIENCE'
        %  this is the science quality version
        DataSet='TQSux10';
        AverageTtype='1day';
        ParamVarName='QSux10';
        FirstFilePartName='QSZONWINDSCI1Day';
        HourStamp='12';
    case 'MERIDIONALQSCATWINDS1DAYSCIENCE'
        %  this is the science quality version
        DataSet='TQSuy10';
        AverageTtype='1day';
        ParamVarName='QSuy10';
        FirstFilePartName='QSMERWINDSCI1Day';
        HourStamp='12';
    case 'ZONALQSCATWINDS3DAY'
        DataSet='TQNux10';
        AverageTtype='3day';
        ParamVarName='QNux10';
        FirstFilePartName='QSCATZONWIND3Day';
        HourStamp='12';
    case 'MERIDIONALQSCATWINDS3DAY'
        DataSet='TQNuy10';
        AverageTtype='3day';
        ParamVarName='QNuy10';
        FirstFilePartName='QSCATMERWIND3Day';
        HourStamp='12';
    case 'AVISOSSH1DAY'
        DataSet='TTAsshl';
        AverageTtype='1day';
        ParamVarName='TAsshl';
        FirstFilePartName='SSH1Day';
        HourStamp='12';
    case 'AVISOSSHDEVIATION1DAY'
        DataSet='TTAsshd';
        AverageTtype='1day';
        ParamVarName='TAsshd';
        FirstFilePartName='SSHDev1DDay';
        HourStamp='12';
    case 'CHLSEAWIFS3DAY'  % data ends in March 2009
        DataSet='TSHchl2';
        AverageTtype='3day';
        ParamVarName='SHchl2';
        FirstFilePartName='SWIFS3Day';
        HourStamp='12';
    case 'CHLADEVIATIONSEAWIFS8DAY' % data ends in March 2009
        DataSet='TSHcde2';
        AverageTtype='8day';
        ParamVarName='SHcde2';
        FirstFilePartName='SWIFSDev8Day';
        HourStamp='00';
    case 'ZONGEOCURRENTS1DAY'  %  as of Jul 2009, data available until Dec 2008
        DataSet='TTAugeo';
        AverageTtype='1day';
        ParamVarName='TAugeo';
        FirstFilePartName='GEOCurrZon1Day';
        HourStamp='12';
    case 'MERGEOCURRENTS1DAY'
        DataSet='TTAvgeo';
        AverageTtype='1day';
        ParamVarName='TAvgeo';
        FirstFilePartName='GEOCurrMer1Day';
        HourStamp='12';
    otherwise
        disp('unknown option chosen')
        disp('routine ending')
        return;
end
%
%  Build up the matrix of dates to obtain
%
TemTimeAxis=datenum([DateStart 12 0 0]):1:datenum([DateEnd 12 0 0]);
NumTimesToCheck=numel(TemTimeAxis);
TemTimeAxis=datevec(TemTimeAxis);
%
FirstLinkPiece=['http://coastwatch.pfel.noaa.gov/coastwatch/CWBrowser.jsp?get=gridData&dataSet='  DataSet];
FirstLinkPiece=[FirstLinkPiece '&timePeriod=' AverageTtype '&centeredTime='];
%
LastLinkPiece=['T' HourStamp ':00:00&maxLat=' num2str(nanmax(LatLims)) '&minLon=' num2str(nanmin(LonLims))];
LastLinkPiece=[LastLinkPiece '&maxLon=' num2str(nanmax(LonLims)) '&minLat=' num2str(nanmin(LatLims)) '&fileType=.mat'];
%
DoAtOnce=30;  % pause after every 20 files to wait before downloading more 
%
TotalGlobalLoops=5;  % loop through the whole set 5 times
%
for jloop=1:TotalGlobalLoops,
    %
    TemStr=['*** ' num2str(jloop) ' of ' num2str(TotalGlobalLoops) ' stepping through ****'];
    AddLineToLog(DirOut,RunTimeLogFile,TemStr);
    disp(TemStr)
    TemStr=['*** File List Trying To Download ***'];
    AddLineToLog(DirOut,RunTimeLogFile,TemStr);
    %
    MarkerNow=0;
    %
    for jtime=1:NumTimesToCheck,
        %
        MarkerNow=MarkerNow+1;
        %
        if MarkerNow>DoAtOnce,
            MarkerNow=1;
            pause(5*60);
        end
        %
        if TemTimeAxis(jtime,2)<10,
            MonthPart=['0' num2str(TemTimeAxis(jtime,2),1)];
        else
            MonthPart=num2str(TemTimeAxis(jtime,2),2);
        end
        %
        if TemTimeAxis(jtime,3)<10,
            DayPart=['0' num2str(TemTimeAxis(jtime,3),1)];
        else
            DayPart=num2str(TemTimeAxis(jtime,3),2);
        end
        %
        YearPart=num2str(TemTimeAxis(jtime,1),4);
        %
        LoadDataSwitch=1;
        %
        FileToSave=[FirstFilePartName YearPart 'M' MonthPart 'D' DayPart 'H12UTC.mat'];
        %
        cd(DirOut);
        %
        if(exist(FileToSave,'file')),
            %
            try
                load(FileToSave);
                if exist(ParamVarName,'var'),
                    eval(['DataToCheck=' ParamVarName ';'])
                else
                    DataToCheck=NaN;
                end
                %
                DataToCheck=nansum(nansum(DataToCheck));
                %
                if ~isnan(DataToCheck),
                    %
                    LoadDataSwitch=0;  % means we have data already loaded
                    %
                end
            catch
                %  do nothing
            end
            %
        end
        %
        if LoadDataSwitch,
            %
            FullLink=[FirstLinkPiece YearPart '-' MonthPart '-' DayPart LastLinkPiece];
            %
            try
                disp(['Trying to download file: ' FileToSave]);
                %
                F=urlwrite(FullLink,FileToSave);
                pause(15);
                %
                AddLineToLog(DirOut,RunTimeLogFile,FileToSave);
                %
            catch
                %  do nothing
            end
        else
             disp(['FILE ALREADY DOWNLOADED: ' FileToSave]);
         end
         %
    end
    %
    %pause(60);  % pause for a minute before looping through again
    pause(8*60);  % pause for 8 minutes before looping through again
    %
end
%
%  we have tried to download the files....  now check to see if the data has made it, and write out a log file
%
AddLineToLog(DirOut,DataCheckLogFile,'********  Checking To See Which Files Made It  ********');
%
for jtime=1:NumTimesToCheck,
    %
    if TemTimeAxis(jtime,2)<10,
        MonthPart=['0' num2str(TemTimeAxis(jtime,2),1)];
    else
        MonthPart=num2str(TemTimeAxis(jtime,2),2);
    end
    %
    if TemTimeAxis(jtime,3)<10,
        DayPart=['0' num2str(TemTimeAxis(jtime,3),1)];
    else
        DayPart=num2str(TemTimeAxis(jtime,3),2);
    end
    %
    YearPart=num2str(TemTimeAxis(jtime,1),4);
    %
    FileToSave=[FirstFilePartName YearPart 'M' MonthPart 'D' DayPart 'H12UTC.mat'];
    %
    cd(DirOut);
    %
    DataLoadedCheck=0;  % assume data not loaded unless otherwise indicated
    %
    if(exist(FileToSave,'file')),
        %
        try
            load(FileToSave);
            if exist(ParamVarName,'var'),
                eval(['DataToCheck=' ParamVarName ';'])
            else
                DataToCheck=NaN;
            end
            %
            DataToCheck=nansum(nansum(DataToCheck));
            if ~isnan(DataToCheck),
                DataLoadedCheck=1;
            end
        catch
            %  do nothing
        end
    end
    %
    if DataLoadedCheck,
        TemStr=[FileToSave ' Loaded'];
    else
        TemStr=[FileToSave ' NOT LOADED'];
    end
    %
    AddLineToLog(DirOut,DataCheckLogFile,TemStr);
    %
    pause(2);
    %
end
%
%  the routine is done
%
return;
