function PlotNonHFRadarData(TemFigHandle,TimeStep,DateNumSelect,TimeAxisIn,DataIn,SymbType,SymbRange,DataRange,ColorMapType,MapPos)
%
%  PlotNonHFRadarData(TemFigHandle,TimeStep,DateNumSelect,TimeAxisIn,DataIn
%  ,SymbType,SymbRange,DataRange,ColorMapType,MapPos);
%
%  to place a symbol on a field of HF Radar velocity vectors
%
%  The value of TimeStep is used to plot the data, unless it is equal to
%  NaN.  If so, the value of DateNumSelect is used to find which value to
%  plot.  TimeAxisIn can be NaN if the TimeStep value is set.
%
%  Example useage, to plot TimeStep 1 with square symbols:
%
% PlotNonHFRadarData(TemFigHandle,1,NaN,NaN,'s',[10 20],[-15 15],'jet',[longitude latitude]);
%
%  modified 21 April 2009 ---  can also plot a full suite of data if
%  TimeStep in is a vector.  In that case, numel(DataIn) should equal
%  numel(longitude).  Only those points indexed by TimeStep will be
%  plotted.
%
%  Inputs:
%
%  TemFigHandle:  the handle of the prviously held figure of CODAR vectors
%  TimeStep:      the number of the data point to plot
%  DataIn:        the scalar Data - can be a row or column vector
%  SymbType:      the symbol to use for plotting - can be 's', or 'o', for
%                 example.  See plot for more details.
%  SymbRange:     The range in size of the symbols (MarkerSize).  Good ranges to use are
%                 [11 20].  Format is [minrange maxrange]
%  DataRange:     The range of the data to use for deciding what color to
%                 make the symbols and to scale the marker sizes
%  ColorMapType:  The colormap to use, see colormap.  'jet' is a good one
%                 if you want to vary from blue to red.
%  MapPos:        The [lon lat] position of the location to plot the
%                 symbol.
%
%  Outputs:       A symbol on the HF Radar map.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% 	$Id: PlotNonHFRadarData.m 2007-08 cmh $	
%
% Copyright (C) 2007 Christopher M. Halle
% Licence: GPL (Gnu Public License)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
figure(TemFigHandle);
%
%  Step 1 - find the TimeStep
%
if numel(TimeStep)<2,
    if isnan(TimeStep),
        if isnan(DateNumSelect),
            disp('both TimeStep and DateNumSelect have been set to NaN')
            disp('PlotNonHFRadarData routine ending')
            return;
        else
            [MinValDate,TimeStep]=min(abs(TimeAxisIn-DateNumSelect));
        end
    end
end
%
try
    eval(['TemMap=' ColorMapType '(100);']);
catch
    disp('error in specifying ColorMapType')
    disp('jet colormap assumed')
    TemMap=jet(100);
end
%
CurrMeas=DataIn(TimeStep);
MapPos=MapPos(TimeStep,:);
%
temmark=find(~isnan(CurrMeas));
if numel(temmark)>0,
    CurrMeas=CurrMeas(temmark);
    MapPos=MapPos(temmark,:);
else
    return;
end
%
[mrows,ncols]=size(CurrMeas);
if ncols>mrows,
   CurrMeas=CurrMeas';  % probably not necessary, but won't hurt anything
   mrows=ncols;
   clear ncols
end
%
FullScale=nanmax(DataRange)-nanmin(DataRange);
PartScale=CurrMeas-nanmin(DataRange);
RelScale=PartScale/FullScale;
RelScaleColor=round(100*RelScale);  % convert to percent to get 0 to 100 values for the colormap
%
RelScaleColor(RelScaleColor<=0)=1;
%
RelScaleColor(RelScaleColor>=100)=100;
%
RelScaleColorUnique=unique(RelScaleColor);
%
SymbDelta=max(SymbRange)-min(SymbRange)+1;
RelScaleSymbol=round(SymbDelta*RelScale);  % convert to get numbers for symbol size
%
RelScaleSymbol(RelScaleSymbol<=0)=1;
RelScaleSymbol(RelScaleSymbol>=SymbDelta)=SymbDelta;
RelScaleSymbolUnique=unique(RelScaleSymbol);
%
%  !!!
%  problem....  we have to plot the different values of TemMarkerSize and
%  TemColor separately
%
for jcolor=1:numel(RelScaleColorUnique),
    for jsymbol=1:numel(RelScaleSymbolUnique),
        temmark1=find(RelScaleColor==RelScaleColorUnique(jcolor));
        temmark2=find(RelScaleSymbol==RelScaleSymbolUnique(jsymbol));
        temmarkall=intersect(temmark1,temmark2);
        if numel(temmarkall)>0,
            TemColor=TemMap(RelScaleColorUnique(jcolor),:);
            TemMarkerSize=RelScaleSymbolUnique(jsymbol)+min(SymbRange)-1;
            m_plot(MapPos(temmarkall,1),MapPos(temmarkall,2),SymbType,'Color',TemColor,'MarkerSize',TemMarkerSize,'LineWidth',[2]);
        end
    end
end
%
%  routine is done
%
return;
%
