function [SerERotated,SerNRotated]=RotateHFMeas(SerEIn,SerNIn,DirectionToUse)
%
%  [SerERotated,SerNRotated]=RotateHFMeas(SerEIn,SerNIn,DirectionToUse);
%
%  to rotate measurements to a given direction, "up coast" is positive, Direction specified as
%  CW from north, in degrees
%
%  CMH
%
%  if numel(DirectionToUse)==1, then all measurements are rotated into teh
%  given direction.  Otherwise, numel(DirectionToUse) should equal the
%  number of LonLat positions (rows of SerEIn and SerNIn)
%
%  DirectionToUse should be a column vector
%  Rows of SerEIn are positions, columns are times
%
[NumPositions,NumTimes]=size(SerEIn);
NumAngles=numel(DirectionToUse);
if isequal(NumAngles,1),
    DirectionToUse=repmat(DirectionToUse,NumPositions,1);
end
%  NumAngles is equal to NumPositions at this point, if things are o.k.
NumAngles=numel(DirectionToUse);
if ~isequal(NumAngles,NumPositions),
    disp('Number of Angles in RotateHFMeas specified incorrectly')
    disp('NaNs being returned in the velocity fields')
    SerERotated=NaN*ones(size(SerEIn));
    SerNRotated=NaN*ones(size(SerNIn));
end
%
Phi=atan2(SerEIn,SerNIn);
Phi=(180/pi)*Phi;
%
temmark=find(Phi<0);
if numel(temmark)>0,
    Phi(temmark)=360+Phi(temmark);
end
%
DirIn=Phi;  % now a matrix, number of rows equal to NumRows, number of columns equal to NumTimes
%
ZMeas=SerEIn+(i*SerNIn);
MagMeas=abs(ZMeas);
clear ZMeas
%
%  Now set up DirectionToUse in matrix format
%
DirectionToUse=DirectionToUse*ones(1,NumTimes);
%
%  we now have the angles
%
%  Get speeds in terms of "up coast" being positive
%
%  Phi is redefined below
%
radianfactor=2*pi/360;
%
Phi=360-DirectionToUse;
NewDir=DirIn+Phi;
%
SerNRotated=(MagMeas.*cos(radianfactor*NewDir));
%
SerERotated=(MagMeas.*sin(radianfactor*NewDir));
%
return;
%
