function GenericRemapLRTotals(RadialType,FileStartNum)
%
%  GenericRemapLRTotals(RadialType,FileStartNum);
%
%  Follows on to GenericLRTotalsPartC - takes the LR totals, and remaps to
%  a higher resolution grid (2km), used for PSUR to PAFS
%
%  This spatially and temporally interpolates the data
%
%  comments from the original LR routines:
%
%  concatenates the hourly totals
%
%  Shoot!  Have to load and interpolate files individually - and worry
%  about wraparound (end of times at start and end of variables).  Maximum
%  size allowed by program exceeded if one tries to do everything at once.
%
%  DMK temporal interpolation is elegant, but a real memory hog!  Need to
%  modify yet again.
%
switch upper(RadialType)
    case 'IDEAL'
        RadialType='Ideal';
    otherwise
        RadialType='Measured';
end
%
GlobalDirIn=cell(1,1);
GlobalDirIn{1}=['/Users/chrishalle/Documents/CODARData/Totals/LongRange/TotalsSetC/' RadialType '/'];
%
GlobalDirOut=['/Users/chrishalle/Documents/CODARData/Totals/LongRange/TotalsSetC/' RadialType '/HighResInterp/'];
%
if ~exist(GlobalDirOut,'dir'),
    %
    [SUCCESS,MESSAGE,MESSAGEID] = mkdir(GlobalDirOut);
    if ~SUCCESS,
        disp('creation of output directory failed')
        disp('routine ending')
        return;
    end
end
%
LogFileName=['LongRangeTotalsPartCInterp' datestr(clock,30) '.txt'];  % the log file
%
%  enter start date and end date for processing
%
StartDate=[2007 6 15 1];  % really only need to enter year and month of start times, but keep this way for ease
EndDate=[2008 6 12 20];   % ideal and measured start / end times roughly the same for BMLR and PAFS
%
%  Get the long range grid used for mapping
%
GridFileDir='/Users/chrishalle/Documents/CODARData/LongRangeNearBML/ProcessingInfo/';
GridFileName='LongRangeGrid5kmVer2.txt';
GridFile=[GridFileDir GridFileName];
%
[LongRangeGrid,fn,c] = loadDataFileWithChecks(GridFile);
%
%  Get the PSURToPAFS high resolution grid
%
GridFileDir='/Users/chrishalle/Documents/CODARData/Totals/PSURToPAFS/ProcessingInfo/';
GridFileName='InitialPSURToPAFSGrid.txt';
GridFile=[GridFileDir GridFileName];
%
[HighResGrid,fn,c] = loadDataFileWithChecks(GridFile);
%
%  Set up a temporary structure so that we can use FindHFBoundingRegion
%
%  We don't want to carry a huge grid to interpolate onto if we don't have to
%
[NumPts]=numel(LongRangeGrid(:,1));
TemStruct=TUVstruct([NumPts 1]);
TemStruct.LonLat=LongRangeGrid;
TemStruct.U=ones(NumPts,1);
TemStruct.V=ones(NumPts,1);
%
[CoverageOut]=FindHFBoundingRegion(TemStruct,1);
%
temmark=find(inpolygon(HighResGrid(:,1),HighResGrid(:,2),CoverageOut(:,1),CoverageOut(:,2)));
%
NewHighResGrid=HighResGrid(temmark,:);
clear temmark NumPts TemStruct CoverageOut LongRangeGrid
%
%  Get years and months to load
%
Spacing=1;
TemStart=datenum([StartDate 0 0]);
TemEnd=datenum([EndDate 0 0]);
TimeVect=TemStart:Spacing/24:TemEnd;
TemVec=datevec(TimeVect);
%
%  problem!!!! datevec routine sometimes gives 59 minutes and 60 seconds
%  instead of converting to the next hour....  check this.
%
temmark=find((TemVec(:,5)>58)&(TemVec(:,6)>58));
if numel(temmark)>0,
    disp('converting some times to next highest hour')
    disp('standard Matlab issue with datevec command')
    TemVec(temmark,4)=TemVec(temmark,4)+1;
    TemVec(temmark,5)=0;
    TemVec(temmark,6)=0;
end
%
TemVec=round(TemVec);
%
TemVecYearMonth=TemVec(:,1:2);
TemVecYearMonth=unique(TemVecYearMonth,'rows');
[NumMonths,NumCols]=size(TemVecYearMonth);
%
%  Method:  Loop through, for each site, load the file for a given month.
%  Load the files for the month before and after, if possible.
%  Extract the individual timestamps into individual radial structures so I can toss everthing into the same Rcat
%  routine (not really necessary, but will take care of the off-chance that
%  the different months have different grid structures?)
%
%  Do for each site.
%
%  Toss the whole mess into the concat routine.
%
%  Get the totals, despike.
%
%  Extract the relevant monthly totals.
%
%  Perform temporal qa/qc.  Save.
%
%
TemStr=['Number of Months To Process: ' num2str(NumMonths)];
AddLineToLog(GlobalDirOut,LogFileName,TemStr);
%
for jmonth=FileStartNum:NumMonths,
    %
    YearMonthToProcess=TemVecYearMonth(jmonth,:);
    %
    if isequal(jmonth,FileStartNum),
        StartClock=clock;
    end
    %
    AddLineToLog(GlobalDirOut,LogFileName,'*****');
    TemStr=['Starting Processing With File Number' num2str(jmonth)];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    AddLineToLog(GlobalDirOut,LogFileName,'*****');
    %    
    TUVorig=LoadTotalsData(GlobalDirIn,RadialType,TemVecYearMonth,jmonth);
    %
    TemStr=['Month Number: ' num2str(jmonth) ', Totals Data Loaded'];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    disp(TemStr)
    %
    if isstruct(TUVorig),
        %
        [TUVorig]=InterpTUVToNewGrid2(TUVorig,NewHighResGrid);
        %
        TemStr=['Month Number: ' num2str(jmonth) ', Totals Remapped to Higher Res Grid'];
        AddLineToLog(GlobalDirOut,LogFileName,TemStr);
        disp(TemStr)
        %
    else
        %
        TUVorig=NaN;
        %
        TemStr=['Month Number: ' num2str(jmonth) ', No Totals Data Found'];
        AddLineToLog(GlobalDirOut,LogFileName,TemStr);
        disp(TemStr)
        %
    end
    %
    %  now save the file
    %
    TemFileName=['BMLLRTotalsPartCRemap' RadialType 'Y' num2str(YearMonthToProcess(1)) 'M' num2str(YearMonthToProcess(2)) '.mat'];
    %
    cd(GlobalDirOut);
    %
    save(TemFileName,'TUVorig');
    %
    pause(2);
    %
    AddLineToLog(GlobalDirOut,LogFileName,'*****');
    TemStr=['Year ' num2str(YearMonthToProcess(1)) ' Month ' num2str(YearMonthToProcess(2)) ' Processed'];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    disp(TemStr)
    TemStr=['Month Number ' num2str(jmonth)];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    AddLineToLog(GlobalDirOut,LogFileName,datestr(clock));
    %
    ElapsedTime=etime(clock,StartClock);
    ElapsedTime=(1/60)*ElapsedTime;
    %
    TemStr=['Elapsed Time in minutes since FileStartNum: ' num2str(ElapsedTime)];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    disp(TemStr)
    %
    AddLineToLog(GlobalDirOut,LogFileName,'*****');
    %    
    clear TUVorig
    %
end
%
%  the routine is done
%
return;
%
function [TUVDataOut]=LoadTotalsData(GlobalDirIn,RadialType,YearMonthsList,MonthNumToLoad)
%
%  [TUVDataOut]=LoadTotalsData(GlobalDirIn,RadType,YearMonthsList,MonthNumT
%  oLoad)
%
%
[NumMonths,ncols]=size(YearMonthsList);
%
YearMonthToLoad=YearMonthsList(MonthNumToLoad,:);
%
%  Get current month
%
cd(GlobalDirIn{1});
%
TemFileName=['BMLLRTotalsPartC' RadialType 'Y' num2str(YearMonthToLoad(1)) 'M' num2str(YearMonthToLoad(2)) '.mat'];
%
try
    %
    load(TemFileName);
    %
    %  remove stats field to be consistent with later structures
    %
    if isfield(TUVorig,'TempStats'),
        TUVorig=rmfield(TUVorig,'TempStats');
    end
    %
    %  remove spatial stats field too
    %
    if isfield(TUVorig,'SpatialStats'),
        TUVorig=rmfield(TUVorig,'SpatialStats');
    end
    %    
    TUVCurrent=TUVorig;
    clear TUVorig
    %
catch
    %
    %  file not found, so TUVCurrent does not exist
    %
end
%  concatenate the date we have found.  If no data found, return a NaN
%
%  if data from  the current month does not exist, return a NaN
%
if ~exist('TUVCurrent','var'),
    TUVDataOut=NaN;
    return;
else
    TUVDataOut=TUVCurrent;
end
%
clear TUVCurrent
%
return;
%
