function GenericSRPSURToPAFSTotalsPartBa(RadialType,FileStartNum)
%
%  GenericSRPSURToPAFSTotalsPartBa(RadialType,FileStartNum)
%
%  added scratch file saving
%
%  Follow on to GenericSRPSURToPAFSTotalsPartA(RadialType,FileStartNum);
%  based on GenericSRPSURToPAFSTotalsPartB(RadialType,FileStartNum)
%  Does the first two spatial stats cleanings and saves the file, instead
%  of continuing.  Used to deal with memory problems if we try and do
%  everything at once.
%
%  Follows on to GenericLRTotalsPartA, which used GDOP and performed a
%  first pass cleaning using temporal statistcs.
%
%  This does for the BML Long Range data (BMLR and PAFS).
%
%  Uses 5 km resolution.
%
%  Sequence:
%
%  Load Totals (as well as parts of totals the month before and after)
%  Spatially Screen, Limits Set 1
%  Spatially Screen, Limits Set 2
%  Temporal Screen, Temporal Limits Set 2
%  Spatially Screen, Limits Set 1
%  Spatially Screen, Limits Set 2
%
switch upper(RadialType)
    case 'IDEAL'
        RadialType='Ideal';
    otherwise
        RadialType='Measured';
end
%
GlobalDirIn=cell(1,1);
GlobalDirIn{1}=['/Users/chrishalle/Documents/CODARData/Totals/StandardRange/PSURToPAFS/TotalsSetA/' RadialType '/'];
%
GlobalDirOut=['/Users/chrishalle/Documents/CODARData/Totals/StandardRange/PSURToPAFS/TotalsSetB/' RadialType '/SpatialPass1/'];
%
if ~exist(GlobalDirOut,'dir'),
    %
    [SUCCESS,MESSAGE,MESSAGEID] = mkdir(GlobalDirOut);
    if ~SUCCESS,
        disp('creation of output directory failed')
        disp('routine ending')
        return;
    end
end
%
LogFileName=['StandardRangeTotalsPartBa' datestr(clock,30) '.txt'];  % the log file
%
%  enter start date and end date for processing
%
StartDate=[2007 6 15 1];  % really only need to enter year and month of start times, but keep this way for ease
EndDate=[2008 6 12 20];   % ideal and measured start / end times roughly the same for BMLR and PAFS
%
%StartDate=[2008 1 0 0];  % really only need to enter year and month of start times, but keep this way for ease
%EndDate=[2008 2 12 20];   % ideal and measured start / end times roughly the same for BMLR and PAFS
%
%StartDate=[2008 1 1 0];  % only want to do for 1 month
%EndDate=[2008 1 31 20];   
%
AverageInterval=1;  % for hourly processing
TimeWindow=(0.49999*AverageInterval)/24;  % to take care of roundoff
%
%  Set up cleaning parameters
%
SpatialCleaningParameters1={'No',[8],'SumDist3','AboveBad';'No',[18],'SumDist5','AboveBad'};
SpatialCleaningParameters2={'No',[8],'SumDist3','AboveBad';'No',[18],'SumDist5','AboveBad';'No',[40],'SumDist10','AboveBad';...
    'No',[60],'AvAngle1p5','AboveBad';'No',[300],'SumAngle1p5','AboveBad';'No',[0.1 2],'AvMagRatio1p5','RangeGood'};
%
TemporalCleaningParameters2={'Yes',[0.003],'MinTotDiff','AboveBad'};
%
MaxGapTDiff2=3;
PerCovWindowSearch2=4;
%
%  Get years and months to load
%
Spacing=1;
TemStart=datenum([StartDate 0 0]);
TemEnd=datenum([EndDate 0 0]);
TimeVect=TemStart:Spacing/24:TemEnd;
TemVec=datevec(TimeVect);
%
%  problem!!!! datevec routine sometimes gives 59 minutes and 60 seconds
%  instead of converting to the next hour....  check this.
%
temmark=find((TemVec(:,5)>58)&(TemVec(:,6)>58));
if numel(temmark)>0,
    disp('converting some times to next highest hour')
    disp('standard Matlab issue with datevec command')
    TemVec(temmark,4)=TemVec(temmark,4)+1;
    TemVec(temmark,5)=0;
    TemVec(temmark,6)=0;
end
%
TemVec=round(TemVec);
%
TemVecYearMonth=TemVec(:,1:2);
TemVecYearMonth=unique(TemVecYearMonth,'rows');
[NumMonths,NumCols]=size(TemVecYearMonth);
%
%  Method:  Loop through, for each site, load the file for a given month.
%  Load the files for the month before and after, if possible.
%  Extract the individual timestamps into individual radial structures so I can toss everthing into the same Rcat
%  routine (not really necessary, but will take care of the off-chance that
%  the different months have different grid structures?)
%
%  Do for each site.
%
%  Toss the whole mess into the concat routine.
%
%  Get the totals, despike.
%
%  Extract the relevant monthly totals.
%
%  Perform temporal qa/qc.  Save.
%
%
TemStr=['Number of Months To Process: ' num2str(NumMonths)];
AddLineToLog(GlobalDirOut,LogFileName,TemStr);
%
for jmonth=FileStartNum:NumMonths,
    %
    YearMonthToProcess=TemVecYearMonth(jmonth,:);
    %
    if isequal(jmonth,FileStartNum),
        StartClock=clock;
    end
    %
    AddLineToLog(GlobalDirOut,LogFileName,'*****');
    TemStr=['Starting Processing With File Number' num2str(jmonth)];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    AddLineToLog(GlobalDirOut,LogFileName,'*****');
    %
    TUVorig=LoadTotalsData(GlobalDirIn,RadialType,TemVecYearMonth,jmonth,PerCovWindowSearch2*2);  % load twice the length
    %  before and after PerCovWindowSearch
    %
    TemStr=['Month Number: ' num2str(jmonth) ', Totals Data Loaded'];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    disp(TemStr)
    %
    %  the data has been loaded, data from the months before and after have
    %  been loaded 
    %
    if isstruct(TUVorig),  % a NaN if we do not have data
    %
    %[TUVorig]=GetHFSpatialStatsInterface(TUVorig);  % getting spatial stats
    %[TUVorig]=GetHFSpatialStatsSlow(TUVorig);  % getting spatial stats
    [TUVorig]=GetHFSpatialStats(TUVorig);  % getting spatial stats
    %
    %
    % !!!
    save TUVscratch.mat
    clear
    pause(2);
    %
    load TUVscratch.mat
    %
    TemStr=['Month Number: ' num2str(jmonth) ', Spatial Stats Obtained'];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    disp(TemStr)
    %
    [TUVorig]=CleanHFSpatialStats(TUVorig,SpatialCleaningParameters1);  % cleaning the array
    %
    %
    % !!!
    save TUVscratch.mat
    clear
    pause(2);
    %
    load TUVscratch.mat
    %
    TemStr=['Month Number: ' num2str(jmonth) ', First Set of Spatial Stats Cleaned'];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    disp(TemStr)
    %
    %[TUVorig]=GetHFSpatialStatsInterface(TUVorig);  % getting spatial stats
    %[TUVorig]=GetHFSpatialStatsSlow(TUVorig);  % getting spatial stats
    [TUVorig]=GetHFSpatialStats(TUVorig);  % getting spatial stats
    %
    %
    % !!!
    save TUVscratch.mat
    clear
    pause(2);
    %
    load TUVscratch.mat
    %
    TemStr=['Month Number: ' num2str(jmonth) ', Spatial Stats Obtained'];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    disp(TemStr)
    %
    [TUVorig]=CleanHFSpatialStats(TUVorig,SpatialCleaningParameters2);  % cleaning the array
    %
    %
    % !!!
    save TUVscratch.mat
    clear
    pause(2);
    %
    load TUVscratch.mat
    %
    TemStr=['Month Number: ' num2str(jmonth) ', Second Set of Spatial Stats Cleaned'];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    disp(TemStr)
    %
    %  now redo for temporal stats
    %
    %[TUVorig]=GetHFTemporalStats(TUVorig,MaxGapTDiff2,PerCovWindowSearch2);  % getting temporal stats  %%% the added special step
    %
    %TemStr=['Month Number: ' num2str(jmonth) ', Temporal Stats Obtained'];
    %AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    %disp(TemStr)
    %    
    %[TUVorig]=CleanHFTemporalStats(TUVorig,TemporalCleaningParameters2);
    %
    %TemStr=['Month Number: ' num2str(jmonth) ', Temporal Stats Cleaned'];
    %AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    %disp(TemStr)
    %    
    %[TUVorig]=GetHFSpatialStats(TUVorig);  % getting spatial stats
    %
    %TemStr=['Month Number: ' num2str(jmonth) ', Spatial Stats Obtained'];
    %AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    %disp(TemStr)
    %    
    %[TUVorig]=CleanHFSpatialStats(TUVorig,SpatialCleaningParameters1);  % cleaning the array
    %
    %TemStr=['Month Number: ' num2str(jmonth) ', First Set of Spatial Stats Cleaned'];
    %AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    %disp(TemStr)
    %    
    %[TUVorig]=GetHFSpatialStats(TUVorig);  % getting spatial stats
    %
    %TemStr=['Month Number: ' num2str(jmonth) ', Spatial Stats Obtained'];
    %AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    %disp(TemStr)
    %    
    %[TUVorig]=CleanHFSpatialStats(TUVorig,SpatialCleaningParameters2);  % cleaning the array
    %
    %TemStr=['Month Number: ' num2str(jmonth) ', Second Set of Spatial Stats Cleaned'];
    %AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    %disp(TemStr)
    %    
    [TUVorig]=ExtractRelevantMonthlyDataB(TUVorig,TemVecYearMonth,jmonth);
    %
    TemStr=['Month Number: ' num2str(jmonth) ', Relevant Monthly Data Extracted'];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    disp(TemStr)
    %
    else
        %
        TUVorig=NaN;
        %
        TemStr=['Month Number: ' num2str(jmonth) ', No Totals Data Found'];
        AddLineToLog(GlobalDirOut,LogFileName,TemStr);
        disp(TemStr)
        %
    end
    %
    %  now save the file
    %
    TemFileName=['PSURToPAFSSRTotalsSpatialPass1' RadialType 'Y' num2str(YearMonthToProcess(1)) 'M' num2str(YearMonthToProcess(2)) '.mat'];
    %
    cd(GlobalDirOut);
    %
    save(TemFileName,'TUVorig');
    %
    pause(2);
    %
    AddLineToLog(GlobalDirOut,LogFileName,'*****');
    TemStr=['Year ' num2str(YearMonthToProcess(1)) ' Month ' num2str(YearMonthToProcess(2)) ' Processed'];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    disp(TemStr)
    TemStr=['Month Number ' num2str(jmonth)];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    AddLineToLog(GlobalDirOut,LogFileName,datestr(clock));
    %
    ElapsedTime=etime(clock,StartClock);
    ElapsedTime=(1/60)*ElapsedTime;
    %
    TemStr=['Elapsed Time in minutes since FileStartNum: ' num2str(ElapsedTime)];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    disp(TemStr)
    %
    AddLineToLog(GlobalDirOut,LogFileName,'*****');
    %    
    clear TUVorig
    %
end
%
%  the routine is done
%
return;
%
function [TUVDataOut]=LoadTotalsData(GlobalDirIn,RadialType,YearMonthsList,MonthNumToLoad,HoursBeforeAndAfter)
%
%  [TUVDataOut]=LoadTotalsData(GlobalDirIn,RadType,YearMonthsList,MonthNumT
%  oLoad,HoursBeforeAndAfter)
%
%
[NumMonths,ncols]=size(YearMonthsList);
%
YearMonthToLoad=YearMonthsList(MonthNumToLoad,:);
%
%  Get current month
%
cd(GlobalDirIn{1});
%
TemFileName=['PSURToPAFSSRTotalsPartA' RadialType 'Y' num2str(YearMonthToLoad(1)) 'M' num2str(YearMonthToLoad(2)) '.mat'];
%
try
    %
    load(TemFileName);
    %
    %  remove stats field to be consistent with later structures
    %
    if isfield(TUVorig,'TempStats'),
        TUVorig=rmfield(TUVorig,'TempStats');
    end
    %
    TUVCurrent=TUVorig;
    clear TUVorig
    %
catch
    %
    %  file not found, so TUVCurrent does not exist
    %
end
%
%  Get data from the month before, if we can
%
if MonthNumToLoad>1,
    %
    YearMonthToLoad=YearMonthsList(MonthNumToLoad-1,:);
    %
    TemFileName=['PSURToPAFSSRTotalsPartA' RadialType 'Y' num2str(YearMonthToLoad(1)) 'M' num2str(YearMonthToLoad(2)) '.mat'];
    %
    try
        %
        load(TemFileName);
        %
        %  remove stats field to be consistent with later structures
        %
        if isfield(TUVorig,'TempStats'),
            TUVorig=rmfield(TUVorig,'TempStats');
        end
        %
        %  extract data from the end of the month
        %
        DataBefore=ExtractTotalsData(TUVorig,'LastMeasurements',HoursBeforeAndAfter,YearMonthToLoad); %DataBefore
        %  a NaN if no data found
        %
        if isstruct(DataBefore),
            TUVBefore=DataBefore;
        end
        %
        clear DataBefore TUVorig
        %
    catch
        %
        %  file not found, so TUVBefore does not exist
        %
    end
    %
end
%
%
%  Get data from the month after, if we can
%
if MonthNumToLoad<NumMonths,
    %
    YearMonthToLoad=YearMonthsList(MonthNumToLoad+1,:);
    %
    TemFileName=['PSURToPAFSSRTotalsPartA' RadialType 'Y' num2str(YearMonthToLoad(1)) 'M' num2str(YearMonthToLoad(2)) '.mat'];
    %
    try
        %
        load(TemFileName);
        %
        %  remove stats field to be consistent with later structures
        %
        if isfield(TUVorig,'TempStats'),
            TUVorig=rmfield(TUVorig,'TempStats');
        end
        %
        %  extract data from the beginning of the month
        %
        DataAfter=ExtractTotalsData(TUVorig,'FirstMeasurements',HoursBeforeAndAfter,YearMonthToLoad); %DataAfter
        %  a NaN if no data found
        %
        if isstruct(DataBefore),
            TUVAfter=DataAfter;
        end
        %
        clear DataAfter TUVorig
        %
    catch
        %
        %  file not found, so TUVAfter does not exist
        %
    end
    %
end
%
%  concatenate the date we have found.  If no data found, return a NaN
%
%  if data from  the current month does not exist, return a NaN
%
if ~exist('TUVCurrent','var'),
    TUVDataOut=NaN;
    return;
end
%
if exist('TUVBefore','var')&&exist('TUVAfter','var'),
    %
    TUVDataOut=temporalConcatTUV(TUVBefore,TUVCurrent,TUVAfter);
elseif exist('TUVBefore','var')&&(~exist('TUVAfter','var')),
    TUVDataOut=temporalConcatTUV(TUVBefore,TUVCurrent);
elseif (~exist('TUVBefore','var'))&&exist('TUVAfter','var'),
    TUVDataOut=temporalConcatTUV(TUVCurrent,TUVAfter);
else
    TUVDataOut=TUVCurrent;
end
%
clear TUVCurrent
%
return;
%
function [TUVOut]=ExtractTotalsData(TUVIn,FirstOrLastSwitch,HoursToExtract,YearMonthToUse)
%
%  [TUVOut]=ExtractTotalsData(TUVIn,FirstOrLastSwitch,HoursToExtract,YearMo
%  nthToUse);
%
%  To extract data at the beginning or the end of a given month -
%  interfaces with the LoadData routine
%
%  Get the time matrix and the year/month of the data passed to the routine
%
%  YearMonthToUse is somewhat redundant here, as we load a timestamp in the
%   TUVIn data and can extract the month.  Keep in case at some point we end
%   up loading slighty more than one month - will save rewriting the
%   routine later.
%
%  Step 1 - Find the timestamps to extract
%
switch upper(FirstOrLastSwitch)
    case 'FIRSTMEASUREMENTS'
        TimeMarkStart=datenum([YearMonthToUse(1) YearMonthToUse(2) 1 0 0 0]);
        TimeMarkEnd=TimeMark+(HoursToExtract/24);
    case 'LASTMEASUREMENTS'
        TimeMarkEnd=datenum([YearMonthToUse(1) YearMonthToUse(2)+1 1 0 0 0]);  % month wraparound during year changes 
        %is o.k. for datenum
        TimeMarkEnd=TimeMarkEnd-(1/24); %subtract one hour to get the end of the month we want
        TimeMarkStart=TimeMarkEnd-(HoursToExtract/24);
end
%
%  find the indices we need
%
TimeIndices=find((TUVIn.TimeStamp>=TimeMarkStart)&(TUVIn.TimeStamp<=TimeMarkEnd));
%
if numel(TimeIndices)>0,
    %
    [NumPoints,NumTimes]=size(TUVIn.U);
    %
    if isfield(TUVIn,'TempStats'),
        TUVIn=rmfield(TUVIn,'TempStats');
    end
    %
    [TUVOut]=subsrefTUV(TUVIn,[1:NumPoints],TimeIndices);
    %
else
    TUVOut=NaN;  % return an "non-structure" (double) if we didn;t iond any data
end
%
%  the routine is done
%
return;
%
function [TUV]=ExtractRelevantMonthlyDataB(TUV,YearMonthsVector,MonthNumber)
%
%  [TUV]=ExtractRelevantMonthlyDataB(TUV,YearMonthsVector,MonthNumber);
%
%  This function extracts the monthly totals data that we want to save
%
%  Difficulty:  We have two stats fields in the totals data that the standard
%  extraction routine cannot handle.  We should probably extract
%  information from the stats as well.
%
%  Get the number of spatial points, and the indices of the times to extract
%
[NumPoints,NumTimes]=size(TUV.U);
%
TemVec=datevec(TUV.TimeStamp);
%
%  problem!!!! datevec routine sometimes gives 59 minutes and 60 seconds
%  instead of converting to the next hour....  check this.
%
temmark=find((TemVec(:,5)>58)&(TemVec(:,6)>58));
if numel(temmark)>0,
    disp('converting some times to next highest hour')
    disp('standard Matlab issue with datevec command')
    TemVec(temmark,4)=TemVec(temmark,4)+1;
    TemVec(temmark,5)=0;
    TemVec(temmark,6)=0;
end
%
TemVec=round(TemVec);
%
YearMonthToExtract=YearMonthsVector(MonthNumber,:);
%
TimeIndex=find(ismember(TemVec(:,1:2),YearMonthToExtract,'rows'));
if numel(TimeIndex)>0,
    TimeIndex=TimeIndex';
end
%
if numel(TimeIndex)<1,
    %
    %  we do not have any data.  Return an empty totals structure
    %
    TUV = TUVstruct([1 1]);
    %
end
%
%  we need to check if the stats field for spatial and temporal statistics
%  are there. If it is, remove it,
%  parse the totals, parse the stats, and reconstruct.
%
if isfield(TUV,'TempStats'),
    TUVStripped=rmfield(TUV,'TempStats');
    TUVTempStats=TUV.TempStats;
else
    TUVStripped=TUV;
end
clear TUV
%
if isfield(TUVStripped,'SpatialStats'),
    TUVSpatialStats=TUVStripped.SpatialStats;
    TUVStripped=rmfield(TUVStripped,'SpatialStats');
end
%
TUVStripped=subsrefTUV(TUVStripped,[1:NumPoints],TimeIndex);
%
if exist('TUVTempStats','var'),
    %
    StatNames=fieldnames(TUVTempStats);
    %
    for jstat=1:numel(StatNames),
        %
        eval(['TemSer=TUVTempStats.' StatNames{jstat} ';'])
        TemSer=TemSer(:,TimeIndex);
        eval(['TUVTempStats.' StatNames{jstat} '=TemSer;'])
        %
    end
end
%
if exist('TUVSpatialStats','var'),
    %
    StatNames=fieldnames(TUVSpatialStats);
    %
    for jstat=1:numel(StatNames),
        %
        eval(['TemSer=TUVSpatialStats.' StatNames{jstat} ';'])
        TemSer=TemSer(:,TimeIndex);
        eval(['TUVSpatialStats.' StatNames{jstat} '=TemSer;'])
        %
    end
end
%
if exist('TUVTempStats','var'),
    %
    TUV=TUVStripped;
    TUV.TempStats=TUVTempStats;
else
    TUV=TUVStripped;
end
%
clear TUVStripped TUVTempStats
%
if exist('TUVSpatialStats','var'),
    %
    TUV.SpatialStats=TUVSpatialStats;
end
%
clear TUVStripped TUVSpatialStats
%
%  the routine is done
%
return;
%
