function MoveRadialFilesMontBay(RadialSite,RadialType)
%
%  MoveRadialFilesMontBay(RadialSite,RadialType);
%
%  To move files from the multiple directories given to one directory
%  Done for the files from Monterey / Santa Cruz passed to me by Julio
%
%  RadialSite is the site (COMM, BML1, etc.)  Set up for my directory
%  structure
%  RadialType is either "Measured" or "Ideal".  If not Ideal, measured is
%  assumed.
%
%  First part of directory names has to begin with the RadialSite - other
%  directories are ignored.  Could add a check for number of characters
%  instead, but this should work.
%  Modified so that first part of directory names do not need to begin with
%  radial site.  They must simply have more than 4 characters to be
%  considered.
%
GlobalInputDir=['/Volumes/Monterey_Bay/' upper(RadialSite)];
%
if isequal(upper(RadialType),'IDEAL'),
    RadialType='Ideal';
    GlobalInputDir=[GlobalInputDir '/RDLi/'];
else
    RadialType='Measured';
    GlobalInputDir=[GlobalInputDir '/RDLm/'];
end
%
DirOut=['/Users/chrishalle/Documents/CODARData/Radials/' upper(RadialSite)];
DirOut=[DirOut '/' RadialType 'All/'];
%
if exist(DirOut,'dir'),
    DirCheck='OutputDirectoryExists';
else
    DirCheck='OutputDirectoryCreated';
    [SUCCESS,MESSAGE,MESSAGEID] = mkdir(DirOut);
    if ~SUCCESS,
        disp('directory attempt failed')
        disp('routine ending')
        return;
    end
end
%
LogFileName=[RadialSite RadialType 'MoveLog' datestr(clock,30) '.txt'];
%
AddLineToLog(DirOut,LogFileName,DirCheck);
%
InitialSize=1000;  %assume we have 1000 files, trim later if need be
DirNamesIn=cell(InitialSize,1);
FileNamesIn=cell(InitialSize,1);
%
cd(GlobalInputDir);
%
%  Get the directories and file names to move
%
FilesFound=0;
%
TemDir=dir;
%
for jdir=1:numel(TemDir),
    if TemDir(jdir).isdir,
        if numel(TemDir(jdir).name)>=numel(RadialSite),
            %if isequal(upper(TemDir(jdir).name(1:numel(RadialSite))),upper(RadialSite)), % we might have a directory with files in it
            if numel(TemDir(jdir).name)>=4, % This is now redundant, but easier than modifying the code above    
                %
                cd(TemDir(jdir).name);  % now in the directory.  Now check for file names
                %
                TemFileDir=dir;
                %
                %  assume it's a file we want if the file names are long
                %  enough
                %
                for jfile=1:numel(TemFileDir),
                    if ~TemFileDir(jfile).isdir, % we want files, not directories
                        if numel(TemFileDir(jfile).name)>=15, %15 is arbitrary
                            %
                            DirWantNow=fullfile(GlobalInputDir,TemDir(jdir).name);
                            FileWantNow=TemFileDir(jfile).name;
                            %
                            FilesFound=FilesFound+1;
                            %
                            if FilesFound>numel(DirNamesIn),
                                %
                                DirNamesIn=[DirNamesIn;cell(InitialSize,1)];
                                FileNamesIn=[FileNamesIn;cell(InitialSize,1)];
                            end
                            %
                            DirNamesIn{FilesFound}=DirWantNow;
                            FileNamesIn{FilesFound}=FileWantNow;
                            %
                        end
                    else
                        %
                        %  we might have found a directory in the list.  
                        %  print this to the log file - we will need to
                        %  check it
                        %
                        if ~(isequal(TemFileDir(jfile).name,'.')||isequal(TemFileDir(jfile).name,'..')),
                            %
                            %  print to the log
                            %
                            TemStr='******************';
                            AddLineToLog(DirOut,LogFileName,TemStr);
                            TemStr=['Another Directory Found, Site: ' RadialSite];
                            AddLineToLog(DirOut,LogFileName,TemStr);
                            TemStr=['Parent Directory: ' TemDir(jdir).name];
                            AddLineToLog(DirOut,LogFileName,TemStr);
                            TemStr=['SubDirectory: ' TemFileDir(jfile).name];
                            AddLineToLog(DirOut,LogFileName,TemStr);
                            TemStr='******************';
                            AddLineToLog(DirOut,LogFileName,TemStr);
                            %
                        end
                    end
                end
                %
                %  now change directories back up one level
                %
                cd ..
                %
            end
        end
    end
end
%
%  now trim the file and directory matrices
%
DirNamesIn=DirNamesIn(1:FilesFound,:);
FileNamesIn=FileNamesIn(1:FilesFound,:);
%
%  we have the list of files at this point
%
MoveFileSuccess=1;  % will set this to zero if we get any errors
%
for jfile=1:FilesFound,
    %
    if isequal(rem(jfile,100),0),
        temstr=['Site: ' RadialSite ' File Number ' num2str(jfile) ' of ' num2str(FilesFound) ' Being Copied'];
        disp(temstr);
    end
    %
    FileToMove=fullfile(DirNamesIn{jfile},FileNamesIn{jfile});
    FileNewName=fullfile(DirOut,FileNamesIn{jfile});  % moving all files to the same directory
    %
    %[STATUS,MESSAGE,MESSAGEID]=movefile(FileToMove,FileNewName);
    [STATUS,MESSAGE,MESSAGEID]=copyfile(FileToMove,FileNewName);
    %
    if ~STATUS,
        %
        MoveFileSuccess=0;
        %
        AddLineToLog(DirOut,LogFileName,'                     ');
        AddLineToLog(DirOut,LogFileName,'*********************');
        AddLineToLog(DirOut,LogFileName,'FileNotCopiedCorrectly');
        AddLineToLog(DirOut,LogFileName,['FileName: ' FileToMove]);
        AddLineToLog(DirOut,LogFileName,MESSAGE);
        AddLineToLog(DirOut,LogFileName,'*********************');
        AddLineToLog(DirOut,LogFileName,'                     ');
        %
    end
end
%
if MoveFileSuccess,
    %
    AddLineToLog(DirOut,LogFileName,'                     ');
    AddLineToLog(DirOut,LogFileName,'*********************');
    AddLineToLog(DirOut,LogFileName,'AllFilesMovedCorrectly');
    AddLineToLog(DirOut,LogFileName,'*********************');
    AddLineToLog(DirOut,LogFileName,'                     ');
end
%
%  the routine is ended
%
return;
%
